# Copyright 2021-2025 Zenauth Ltd.
# SPDX-License-Identifier: Apache-2.0

import zipfile
from io import BytesIO
from pathlib import Path
from typing import Iterable

from cerbos.sdk.hub.store_model import File


def zip_directory(directory: Path) -> bytes:
    mem = BytesIO()
    with zipfile.ZipFile(mem, mode="w") as memzip:
        for f in _list_files(directory):
            memzip.write(f, f.relative_to(directory))

    return mem.getvalue()


def iter_files(directory: Path) -> Iterable[File]:
    for f in _list_files(directory):
        store_file_name = f.relative_to(directory)
        contents = f.read_bytes()
        if len(contents) > 0:
            yield File(path=store_file_name.__str__(), contents=contents)


def _list_files(directory: Path) -> Iterable[Path]:
    for root, dirs, files in directory.walk(top_down=True):
        for f in files:
            if (not f.startswith(".")) and (f.endswith((".yaml", ".yml", ".json"))):
                yield root / f

        dirs[:] = [d for d in dirs if not d.startswith(".")]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cerbos/cloud/bootstrap/v1/bootstrap.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cerbos/cloud/bootstrap/v1/bootstrap.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from cerbos.cloud.bundle.v1 import bundle_pb2 as cerbos_dot_cloud_dot_bundle_dot_v1_dot_bundle__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)cerbos/cloud/bootstrap/v1/bootstrap.proto\x12\x19\x63\x65rbos.cloud.bootstrap.v1\x1a\x1b\x62uf/validate/validate.proto\x1a#cerbos/cloud/bundle/v1/bundle.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x94\x02\n\tPDPConfig\x12\x45\n\x04meta\x18\x01 \x01(\x0b\x32).cerbos.cloud.bootstrap.v1.PDPConfig.MetaB\x06\xbaH\x03\xc8\x01\x01R\x04meta\x12K\n\x0b\x62undle_info\x18\x02 \x01(\x0b\x32\".cerbos.cloud.bundle.v1.BundleInfoB\x06\xbaH\x03\xc8\x01\x01R\nbundleInfo\x1as\n\x04Meta\x12\x41\n\ncreated_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xbaH\x03\xc8\x01\x01R\tcreatedAt\x12(\n\x0b\x63ommit_hash\x18\x02 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\ncommitHashB\x8c\x01\n!dev.cerbos.api.cloud.v1.bootstrapZGgithub.com/cerbos/cloud-api/genpb/cerbos/cloud/bootstrap/v1;bootstrapv1\xaa\x02\x1d\x43\x65rbos.Api.Cloud.V1.Bootstrapb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cerbos.cloud.bootstrap.v1.bootstrap_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!dev.cerbos.api.cloud.v1.bootstrapZGgithub.com/cerbos/cloud-api/genpb/cerbos/cloud/bootstrap/v1;bootstrapv1\252\002\035Cerbos.Api.Cloud.V1.Bootstrap'
  _globals['_PDPCONFIG_META'].fields_by_name['created_at']._loaded_options = None
  _globals['_PDPCONFIG_META'].fields_by_name['created_at']._serialized_options = b'\272H\003\310\001\001'
  _globals['_PDPCONFIG_META'].fields_by_name['commit_hash']._loaded_options = None
  _globals['_PDPCONFIG_META'].fields_by_name['commit_hash']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_PDPCONFIG'].fields_by_name['meta']._loaded_options = None
  _globals['_PDPCONFIG'].fields_by_name['meta']._serialized_options = b'\272H\003\310\001\001'
  _globals['_PDPCONFIG'].fields_by_name['bundle_info']._loaded_options = None
  _globals['_PDPCONFIG'].fields_by_name['bundle_info']._serialized_options = b'\272H\003\310\001\001'
  _globals['_PDPCONFIG']._serialized_start=172
  _globals['_PDPCONFIG']._serialized_end=448
  _globals['_PDPCONFIG_META']._serialized_start=333
  _globals['_PDPCONFIG_META']._serialized_end=448
# @@protoc_insertion_point(module_scope)



# Copyright 2021-2025 Zenauth Ltd.
# SPDX-License-Identifier: Apache-2.0

from typing import Any, Callable, List, NamedTuple, Optional, Union

import grpc

from cerbos.sdk._async._hub._auth import _AsyncAuthClient


class _AsyncClientCallDetails(NamedTuple):
    method: str
    timeout: Optional[float]
    metadata: Optional[grpc.aio.Metadata]
    credentials: Optional[grpc.CallCredentials]
    wait_for_ready: Optional[bool]


class _AsyncClientCallDetailsWrapper(
    _AsyncClientCallDetails, grpc.aio.ClientCallDetails
):
    pass


class _AsyncAuthInterceptor(
    grpc.aio.UnaryUnaryClientInterceptor,
    grpc.aio.UnaryStreamClientInterceptor,
    grpc.aio.StreamUnaryClientInterceptor,
    grpc.aio.StreamStreamClientInterceptor,
):
    _auth_client: _AsyncAuthClient

    def __init__(
        self,
        auth_client: _AsyncAuthClient,
    ):
        self._auth_client = auth_client

    async def _intercept(
        self,
        continuation: Callable[..., Any],
        client_call_details: grpc.aio.ClientCallDetails,
        request: Any,
    ):
        token = await self._auth_client.authenticate()
        metadata = client_call_details.metadata or grpc.aio.Metadata()
        metadata.add("x-cerbos-auth", token)
        new_client_call_details = _AsyncClientCallDetailsWrapper(
            client_call_details.method,
            client_call_details.timeout,
            metadata,
            client_call_details.credentials,
            client_call_details.wait_for_ready,
        )
        return await continuation(new_client_call_details, request)

    async def intercept_unary_unary(
        self,
        continuation: Callable[
            [grpc.aio.ClientCallDetails, grpc.aio._typing.RequestType],
            grpc.aio.UnaryUnaryCall,
        ],
        client_call_details: grpc.aio.ClientCallDetails,
        request: grpc.aio._typing.RequestType,
    ) -> Union[grpc.aio.UnaryUnaryCall, object]:
        return await self._intercept(continuation, client_call_details, request)

    async def intercept_unary_stream(
        self,
        continuation: Callable[
            [grpc.aio.ClientCallDetails, grpc.aio._typing.RequestType],
            grpc.aio.UnaryStreamCall,
        ],
        client_call_details: grpc.aio.ClientCallDetails,
        request: grpc.aio._typing.RequestType,
    ) -> Union[grpc.aio._typing.ResponseIterableType, grpc.aio.UnaryStreamCall]:
        return await self._intercept(continuation, client_call_details, request)

    async def intercept_stream_unary(
        self,
        continuation: Callable[
            [grpc.aio.ClientCallDetails, grpc.aio._typing.RequestType],
            grpc.aio.StreamUnaryCall,
        ],
        client_call_details: grpc.aio.ClientCallDetails,
        request_iterator: grpc.aio._typing.RequestIterableType,
    ) -> grpc.aio._call.StreamUnaryCall:
        return await self._intercept(
            continuation, client_call_details, request_iterator
        )

    async def intercept_stream_stream(
        self,
        continuation: Callable[
            [grpc.aio.ClientCallDetails, grpc.aio._typing.RequestType],
            grpc.aio.StreamStreamCall,
        ],
        client_call_details: grpc.aio.ClientCallDetails,
        request_iterator: grpc.aio._typing.RequestIterableType,
    ) -> Union[grpc.aio._typing.ResponseIterableType, grpc.aio.StreamStreamCall]:
        return await self._intercept(
            continuation, client_call_details, request_iterator
        )


# grpc.aio classes are annoyingly different from the non-async version so we need a second, slightly-different non-async implementation.


class _ClientCallDetails(NamedTuple):
    method: str
    timeout: Optional[float]
    metadata: Optional[List]
    credentials: Optional[grpc.CallCredentials]
    wait_for_ready: Optional[bool]
    compression: Optional[grpc.Compression]


# Dummy placeholder so that the non-async interceptor type-checks.
class _ClientCallDetailsWrapper(_ClientCallDetails, grpc.ClientCallDetails):
    pass


# Dummy placeholder so that the non-async interceptor type-checks.
class _AuthClient:
    pass


class _AuthInterceptor(
    grpc.UnaryUnaryClientInterceptor,
    grpc.UnaryStreamClientInterceptor,
    grpc.StreamUnaryClientInterceptor,
    grpc.StreamStreamClientInterceptor,
):
    _auth_client: _AuthClient

    def __init__(
        self,
        auth_client: _AuthClient,
    ):
        self._auth_client = auth_client

    async def _intercept(
        self,
        continuation: Callable[..., Any],
        client_call_details: grpc.ClientCallDetails,
        request: Any,
    ):
        token = await self._auth_client.authenticate()
        metadata = client_call_details.metadata or []
        metadata.append(("x-cerbos-auth", token))
        new_client_call_details = _ClientCallDetailsWrapper(
            client_call_details.method,
            client_call_details.timeout,
            metadata,
            client_call_details.credentials,
            client_call_details.wait_for_ready,
            client_call_details.compression,
        )
        return continuation(new_client_call_details, request)

    def intercept_unary_unary(
        self,
        continuation,
        client_call_details,
        request,
    ):
        return self._intercept(continuation, client_call_details, request)

    def intercept_unary_stream(
        self,
        continuation,
        client_call_details,
        request,
    ):
        return self._intercept(continuation, client_call_details, request)

    def intercept_stream_unary(
        self,
        continuation,
        client_call_details,
        request_iterator,
    ):
        return self._intercept(continuation, client_call_details, request_iterator)

    def intercept_stream_stream(
        self,
        continuation,
        client_call_details,
        request_iterator,
    ):
        return self._intercept(continuation, client_call_details, request_iterator)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cerbos/cloud/apikey/v1/apikey.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cerbos/cloud/apikey/v1/apikey.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#cerbos/cloud/apikey/v1/apikey.proto\x12\x16\x63\x65rbos.cloud.apikey.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1bgoogle/api/visibility.proto\x1a\x1egoogle/protobuf/duration.proto\"n\n\x17IssueAccessTokenRequest\x12%\n\tclient_id\x18\x01 \x01(\tB\x08\xbaH\x05r\x03\x98\x01\x0cR\x08\x63lientId\x12,\n\rclient_secret\x18\x02 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x0c\x63lientSecret\"\x88\x01\n\x18IssueAccessTokenResponse\x12*\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x0b\x61\x63\x63\x65ssToken\x12@\n\nexpires_in\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x06\xbaH\x03\xc8\x01\x01R\texpiresIn2\x9e\x01\n\rApiKeyService\x12w\n\x10IssueAccessToken\x12/.cerbos.cloud.apikey.v1.IssueAccessTokenRequest\x1a\x30.cerbos.cloud.apikey.v1.IssueAccessTokenResponse\"\x00\x1a\x14\xfa\xd2\xe4\x93\x02\x0e\x12\x0c\x45XPERIMENTALB\x80\x01\n\x1e\x64\x65v.cerbos.api.cloud.v1.apikeyZAgithub.com/cerbos/cloud-api/genpb/cerbos/cloud/apikey/v1;apikeyv1\xaa\x02\x1a\x43\x65rbos.Api.Cloud.V1.ApiKeyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cerbos.cloud.apikey.v1.apikey_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036dev.cerbos.api.cloud.v1.apikeyZAgithub.com/cerbos/cloud-api/genpb/cerbos/cloud/apikey/v1;apikeyv1\252\002\032Cerbos.Api.Cloud.V1.ApiKey'
  _globals['_ISSUEACCESSTOKENREQUEST'].fields_by_name['client_id']._loaded_options = None
  _globals['_ISSUEACCESSTOKENREQUEST'].fields_by_name['client_id']._serialized_options = b'\272H\005r\003\230\001\014'
  _globals['_ISSUEACCESSTOKENREQUEST'].fields_by_name['client_secret']._loaded_options = None
  _globals['_ISSUEACCESSTOKENREQUEST'].fields_by_name['client_secret']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_ISSUEACCESSTOKENRESPONSE'].fields_by_name['access_token']._loaded_options = None
  _globals['_ISSUEACCESSTOKENRESPONSE'].fields_by_name['access_token']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_ISSUEACCESSTOKENRESPONSE'].fields_by_name['expires_in']._loaded_options = None
  _globals['_ISSUEACCESSTOKENRESPONSE'].fields_by_name['expires_in']._serialized_options = b'\272H\003\310\001\001'
  _globals['_APIKEYSERVICE']._loaded_options = None
  _globals['_APIKEYSERVICE']._serialized_options = b'\372\322\344\223\002\016\022\014EXPERIMENTAL'
  _globals['_ISSUEACCESSTOKENREQUEST']._serialized_start=153
  _globals['_ISSUEACCESSTOKENREQUEST']._serialized_end=263
  _globals['_ISSUEACCESSTOKENRESPONSE']._serialized_start=266
  _globals['_ISSUEACCESSTOKENRESPONSE']._serialized_end=402
  _globals['_APIKEYSERVICE']._serialized_start=405
  _globals['_APIKEYSERVICE']._serialized_end=563
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cerbos/cloud/store/v1/store.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cerbos/cloud/store/v1/store.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!cerbos/cloud/store/v1/store.proto\x12\x15\x63\x65rbos.cloud.store.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1bgoogle/api/visibility.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xc4\x01\n\x0bStringMatch\x12\x18\n\x06\x65quals\x18\x01 \x01(\tH\x00R\x06\x65quals\x12\x1c\n\x08\x63ontains\x18\x02 \x01(\tH\x00R\x08\x63ontains\x12;\n\x02in\x18\x03 \x01(\x0b\x32).cerbos.cloud.store.v1.StringMatch.InListH\x00R\x02in\x1a\x30\n\x06InList\x12&\n\x06values\x18\x01 \x03(\tB\x0e\xbaH\x0b\x92\x01\x08\x10\n\"\x04r\x02\x10\x01R\x06valuesB\x0e\n\x05match\x12\x05\xbaH\x02\x08\x01\"R\n\nFileFilter\x12;\n\x04path\x18\x01 \x01(\x0b\x32\".cerbos.cloud.store.v1.StringMatchH\x00R\x04path\x88\x01\x01\x42\x07\n\x05_path\"\x82\x01\n\x10ListFilesRequest\x12#\n\x08store_id\x18\x01 \x01(\tB\x08\xbaH\x05r\x03\x98\x01\x0cR\x07storeId\x12>\n\x06\x66ilter\x18\x02 \x01(\x0b\x32!.cerbos.cloud.store.v1.FileFilterH\x00R\x06\x66ilter\x88\x01\x01\x42\t\n\x07_filter\"N\n\x11ListFilesResponse\x12#\n\rstore_version\x18\x01 \x01(\x03R\x0cstoreVersion\x12\x14\n\x05\x66iles\x18\x02 \x03(\tR\x05\x66iles\"`\n\x0fGetFilesRequest\x12#\n\x08store_id\x18\x01 \x01(\tB\x08\xbaH\x05r\x03\x98\x01\x0cR\x07storeId\x12(\n\x05\x66iles\x18\x02 \x03(\tB\x12\xbaH\x0f\x92\x01\x0c\x08\x01\x10\n\x18\x01\"\x04r\x02\x10\x01R\x05\x66iles\"P\n\x04\x46ile\x12\x1e\n\x04path\x18\x01 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\x80\x08R\x04path\x12(\n\x08\x63ontents\x18\x02 \x01(\x0c\x42\x0c\xbaH\tz\x07\x10\x01\x18\x80\x80\xc0\x02R\x08\x63ontents\"j\n\x10GetFilesResponse\x12#\n\rstore_version\x18\x01 \x01(\x03R\x0cstoreVersion\x12\x31\n\x05\x66iles\x18\x02 \x03(\x0b\x32\x1b.cerbos.cloud.store.v1.FileR\x05\x66iles\"\xbf\x07\n\rChangeDetails\x12 \n\x0b\x64\x65scription\x18\x01 \x01(\tR\x0b\x64\x65scription\x12I\n\x08uploader\x18\x02 \x01(\x0b\x32-.cerbos.cloud.store.v1.ChangeDetails.UploaderR\x08uploader\x12<\n\x03git\x18\x03 \x01(\x0b\x32(.cerbos.cloud.store.v1.ChangeDetails.GitH\x00R\x03git\x12K\n\x08internal\x18\x04 \x01(\x0b\x32-.cerbos.cloud.store.v1.ChangeDetails.InternalH\x00R\x08internal\x1a\x89\x02\n\x03Git\x12\x12\n\x04repo\x18\x01 \x01(\tR\x04repo\x12\x10\n\x03ref\x18\x02 \x01(\tR\x03ref\x12\x12\n\x04hash\x18\x03 \x01(\tR\x04hash\x12\x18\n\x07message\x18\x04 \x01(\tR\x07message\x12\x1c\n\tcommitter\x18\x05 \x01(\tR\tcommitter\x12;\n\x0b\x63ommit_date\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ncommitDate\x12\x16\n\x06\x61uthor\x18\x07 \x01(\tR\x06\x61uthor\x12;\n\x0b\x61uthor_date\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nauthorDate\x1a\xd0\x01\n\x08Internal\x12\x16\n\x06source\x18\x01 \x01(\tR\x06source\x12W\n\x08metadata\x18\x02 \x03(\x0b\x32;.cerbos.cloud.store.v1.ChangeDetails.Internal.MetadataEntryR\x08metadata\x1aS\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.ValueR\x05value:\x02\x38\x01\x1a\xcc\x01\n\x08Uploader\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12W\n\x08metadata\x18\x02 \x03(\x0b\x32;.cerbos.cloud.store.v1.ChangeDetails.Uploader.MetadataEntryR\x08metadata\x1aS\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.ValueR\x05value:\x02\x38\x01\x42\x08\n\x06origin\"r\n\x06\x46ileOp\x12\x41\n\radd_or_update\x18\x01 \x01(\x0b\x32\x1b.cerbos.cloud.store.v1.FileH\x00R\x0b\x61\x64\x64OrUpdate\x12\x18\n\x06\x64\x65lete\x18\x02 \x01(\tH\x00R\x06\x64\x65leteB\x0b\n\x02op\x12\x05\xbaH\x02\x08\x01\"\x9e\x03\n\x12ModifyFilesRequest\x12#\n\x08store_id\x18\x01 \x01(\tB\x08\xbaH\x05r\x03\x98\x01\x0cR\x07storeId\x12V\n\tcondition\x18\x02 \x01(\x0b\x32\x33.cerbos.cloud.store.v1.ModifyFilesRequest.ConditionH\x00R\tcondition\x88\x01\x01\x12I\n\noperations\x18\x03 \x03(\x0b\x32\x1d.cerbos.cloud.store.v1.FileOpB\n\xbaH\x07\x92\x01\x04\x08\x01\x10\x19R\noperations\x12P\n\x0e\x63hange_details\x18\x04 \x01(\x0b\x32$.cerbos.cloud.store.v1.ChangeDetailsH\x01R\rchangeDetails\x88\x01\x01\x1aM\n\tCondition\x12@\n\x18store_version_must_equal\x18\x01 \x01(\x03\x42\x07\xbaH\x04\"\x02(\x00R\x15storeVersionMustEqualB\x0c\n\n_conditionB\x11\n\x0f_change_details\"\xb5\x02\n\tFileError\x12\x12\n\x04\x66ile\x18\x01 \x01(\tR\x04\x66ile\x12<\n\x05\x63\x61use\x18\x02 \x01(\x0e\x32&.cerbos.cloud.store.v1.FileError.CauseR\x05\x63\x61use\x12\x18\n\x07\x64\x65tails\x18\x03 \x01(\tR\x07\x64\x65tails\"\xbb\x01\n\x05\x43\x61use\x12\x15\n\x11\x43\x41USE_UNSPECIFIED\x10\x00\x12\x1b\n\x17\x43\x41USE_INVALID_FILE_PATH\x10\x01\x12$\n CAUSE_UNSUPPORTED_FILE_EXTENSION\x10\x02\x12\x1f\n\x1b\x43\x41USE_INVALID_FILE_CONTENTS\x10\x03\x12\x1d\n\x19\x43\x41USE_DUPLICATE_FILE_PATH\x10\x04\x12\x18\n\x14\x43\x41USE_FILE_TOO_LARGE\x10\x05\"A\n\x13ModifyFilesResponse\x12*\n\x11new_store_version\x18\x01 \x01(\x03R\x0fnewStoreVersion\"\x83\x05\n\x13ReplaceFilesRequest\x12#\n\x08store_id\x18\x01 \x01(\tB\x08\xbaH\x05r\x03\x98\x01\x0cR\x07storeId\x12W\n\tcondition\x18\x02 \x01(\x0b\x32\x34.cerbos.cloud.store.v1.ReplaceFilesRequest.ConditionH\x01R\tcondition\x88\x01\x01\x12\x37\n\x0fzipped_contents\x18\x03 \x01(\x0c\x42\x0c\xbaH\tz\x07\x10\x16\x18\x80\x80\xc0\x07H\x00R\x0ezippedContents\x12H\n\x05\x66iles\x18\x05 \x01(\x0b\x32\x30.cerbos.cloud.store.v1.ReplaceFilesRequest.FilesH\x00R\x05\x66iles\x12P\n\x0e\x63hange_details\x18\x04 \x01(\x0b\x32$.cerbos.cloud.store.v1.ChangeDetailsH\x02R\rchangeDetails\x88\x01\x01\x1aM\n\tCondition\x12@\n\x18store_version_must_equal\x18\x01 \x01(\x03\x42\x07\xbaH\x04\"\x02(\x00R\x15storeVersionMustEqual\x1a\x95\x01\n\x05\x46iles\x12\x8b\x01\n\x05\x66iles\x18\x01 \x03(\x0b\x32\x1b.cerbos.cloud.store.v1.FileBX\xbaHU\x92\x01\x02\x08\x01\xba\x01M\n\x12\x66iles.unique_paths\x12\x19\x46ile paths must be unique\x1a\x1cthis.map(f, f.path).unique()R\x05\x66ilesB\x11\n\x08\x63ontents\x12\x05\xbaH\x02\x08\x01\x42\x0c\n\n_conditionB\x11\n\x0f_change_details\"V\n\x1a\x45rrDetailValidationFailure\x12\x38\n\x06\x65rrors\x18\x01 \x03(\x0b\x32 .cerbos.cloud.store.v1.FileErrorR\x06\x65rrors\"=\n\x16\x45rrDetailNoUsableFiles\x12#\n\rignored_files\x18\x01 \x03(\tR\x0cignoredFiles\"S\n\x1d\x45rrDetailConditionUnsatisfied\x12\x32\n\x15\x63urrent_store_version\x18\x01 \x01(\x03R\x13\x63urrentStoreVersion\"v\n\x1b\x45rrDetailOperationDiscarded\x12\x32\n\x15\x63urrent_store_version\x18\x01 \x01(\x03R\x13\x63urrentStoreVersion\x12#\n\rignored_files\x18\x02 \x03(\tR\x0cignoredFiles\"(\n&ErrDetailCannotModifyGitConnectedStore\"g\n\x14ReplaceFilesResponse\x12*\n\x11new_store_version\x18\x01 \x01(\x03R\x0fnewStoreVersion\x12#\n\rignored_files\x18\x02 \x03(\tR\x0cignoredFiles2\xc4\x03\n\x12\x43\x65rbosStoreService\x12\x63\n\tListFiles\x12\'.cerbos.cloud.store.v1.ListFilesRequest\x1a(.cerbos.cloud.store.v1.ListFilesResponse\"\x03\x90\x02\x01\x12`\n\x08GetFiles\x12&.cerbos.cloud.store.v1.GetFilesRequest\x1a\'.cerbos.cloud.store.v1.GetFilesResponse\"\x03\x90\x02\x01\x12\x66\n\x0bModifyFiles\x12).cerbos.cloud.store.v1.ModifyFilesRequest\x1a*.cerbos.cloud.store.v1.ModifyFilesResponse\"\x00\x12i\n\x0cReplaceFiles\x12*.cerbos.cloud.store.v1.ReplaceFilesRequest\x1a+.cerbos.cloud.store.v1.ReplaceFilesResponse\"\x00\x1a\x14\xfa\xd2\xe4\x93\x02\x0e\x12\x0c\x45XPERIMENTALB|\n\x1d\x64\x65v.cerbos.api.cloud.v1.storeZ?github.com/cerbos/cloud-api/genpb/cerbos/cloud/store/v1;storev1\xaa\x02\x19\x43\x65rbos.Api.Cloud.V1.Storeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cerbos.cloud.store.v1.store_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\035dev.cerbos.api.cloud.v1.storeZ?github.com/cerbos/cloud-api/genpb/cerbos/cloud/store/v1;storev1\252\002\031Cerbos.Api.Cloud.V1.Store'
  _globals['_STRINGMATCH_INLIST'].fields_by_name['values']._loaded_options = None
  _globals['_STRINGMATCH_INLIST'].fields_by_name['values']._serialized_options = b'\272H\013\222\001\010\020\n\"\004r\002\020\001'
  _globals['_STRINGMATCH'].oneofs_by_name['match']._loaded_options = None
  _globals['_STRINGMATCH'].oneofs_by_name['match']._serialized_options = b'\272H\002\010\001'
  _globals['_LISTFILESREQUEST'].fields_by_name['store_id']._loaded_options = None
  _globals['_LISTFILESREQUEST'].fields_by_name['store_id']._serialized_options = b'\272H\005r\003\230\001\014'
  _globals['_GETFILESREQUEST'].fields_by_name['store_id']._loaded_options = None
  _globals['_GETFILESREQUEST'].fields_by_name['store_id']._serialized_options = b'\272H\005r\003\230\001\014'
  _globals['_GETFILESREQUEST'].fields_by_name['files']._loaded_options = None
  _globals['_GETFILESREQUEST'].fields_by_name['files']._serialized_options = b'\272H\017\222\001\014\010\001\020\n\030\001\"\004r\002\020\001'
  _globals['_FILE'].fields_by_name['path']._loaded_options = None
  _globals['_FILE'].fields_by_name['path']._serialized_options = b'\272H\007r\005\020\001\030\200\010'
  _globals['_FILE'].fields_by_name['contents']._loaded_options = None
  _globals['_FILE'].fields_by_name['contents']._serialized_options = b'\272H\tz\007\020\001\030\200\200\300\002'
  _globals['_CHANGEDETAILS_INTERNAL_METADATAENTRY']._loaded_options = None
  _globals['_CHANGEDETAILS_INTERNAL_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_CHANGEDETAILS_UPLOADER_METADATAENTRY']._loaded_options = None
  _globals['_CHANGEDETAILS_UPLOADER_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_FILEOP'].oneofs_by_name['op']._loaded_options = None
  _globals['_FILEOP'].oneofs_by_name['op']._serialized_options = b'\272H\002\010\001'
  _globals['_MODIFYFILESREQUEST_CONDITION'].fields_by_name['store_version_must_equal']._loaded_options = None
  _globals['_MODIFYFILESREQUEST_CONDITION'].fields_by_name['store_version_must_equal']._serialized_options = b'\272H\004\"\002(\000'
  _globals['_MODIFYFILESREQUEST'].fields_by_name['store_id']._loaded_options = None
  _globals['_MODIFYFILESREQUEST'].fields_by_name['store_id']._serialized_options = b'\272H\005r\003\230\001\014'
  _globals['_MODIFYFILESREQUEST'].fields_by_name['operations']._loaded_options = None
  _globals['_MODIFYFILESREQUEST'].fields_by_name['operations']._serialized_options = b'\272H\007\222\001\004\010\001\020\031'
  _globals['_REPLACEFILESREQUEST_CONDITION'].fields_by_name['store_version_must_equal']._loaded_options = None
  _globals['_REPLACEFILESREQUEST_CONDITION'].fields_by_name['store_version_must_equal']._serialized_options = b'\272H\004\"\002(\000'
  _globals['_REPLACEFILESREQUEST_FILES'].fields_by_name['files']._loaded_options = None
  _globals['_REPLACEFILESREQUEST_FILES'].fields_by_name['files']._serialized_options = b'\272HU\222\001\002\010\001\272\001M\n\022files.unique_paths\022\031File paths must be unique\032\034this.map(f, f.path).unique()'
  _globals['_REPLACEFILESREQUEST'].oneofs_by_name['contents']._loaded_options = None
  _globals['_REPLACEFILESREQUEST'].oneofs_by_name['contents']._serialized_options = b'\272H\002\010\001'
  _globals['_REPLACEFILESREQUEST'].fields_by_name['store_id']._loaded_options = None
  _globals['_REPLACEFILESREQUEST'].fields_by_name['store_id']._serialized_options = b'\272H\005r\003\230\001\014'
  _globals['_REPLACEFILESREQUEST'].fields_by_name['zipped_contents']._loaded_options = None
  _globals['_REPLACEFILESREQUEST'].fields_by_name['zipped_contents']._serialized_options = b'\272H\tz\007\020\026\030\200\200\300\007'
  _globals['_CERBOSSTORESERVICE']._loaded_options = None
  _globals['_CERBOSSTORESERVICE']._serialized_options = b'\372\322\344\223\002\016\022\014EXPERIMENTAL'
  _globals['_CERBOSSTORESERVICE'].methods_by_name['ListFiles']._loaded_options = None
  _globals['_CERBOSSTORESERVICE'].methods_by_name['ListFiles']._serialized_options = b'\220\002\001'
  _globals['_CERBOSSTORESERVICE'].methods_by_name['GetFiles']._loaded_options = None
  _globals['_CERBOSSTORESERVICE'].methods_by_name['GetFiles']._serialized_options = b'\220\002\001'
  _globals['_STRINGMATCH']._serialized_start=182
  _globals['_STRINGMATCH']._serialized_end=378
  _globals['_STRINGMATCH_INLIST']._serialized_start=314
  _globals['_STRINGMATCH_INLIST']._serialized_end=362
  _globals['_FILEFILTER']._serialized_start=380
  _globals['_FILEFILTER']._serialized_end=462
  _globals['_LISTFILESREQUEST']._serialized_start=465
  _globals['_LISTFILESREQUEST']._serialized_end=595
  _globals['_LISTFILESRESPONSE']._serialized_start=597
  _globals['_LISTFILESRESPONSE']._serialized_end=675
  _globals['_GETFILESREQUEST']._serialized_start=677
  _globals['_GETFILESREQUEST']._serialized_end=773
  _globals['_FILE']._serialized_start=775
  _globals['_FILE']._serialized_end=855
  _globals['_GETFILESRESPONSE']._serialized_start=857
  _globals['_GETFILESRESPONSE']._serialized_end=963
  _globals['_CHANGEDETAILS']._serialized_start=966
  _globals['_CHANGEDETAILS']._serialized_end=1925
  _globals['_CHANGEDETAILS_GIT']._serialized_start=1232
  _globals['_CHANGEDETAILS_GIT']._serialized_end=1497
  _globals['_CHANGEDETAILS_INTERNAL']._serialized_start=1500
  _globals['_CHANGEDETAILS_INTERNAL']._serialized_end=1708
  _globals['_CHANGEDETAILS_INTERNAL_METADATAENTRY']._serialized_start=1625
  _globals['_CHANGEDETAILS_INTERNAL_METADATAENTRY']._serialized_end=1708
  _globals['_CHANGEDETAILS_UPLOADER']._serialized_start=1711
  _globals['_CHANGEDETAILS_UPLOADER']._serialized_end=1915
  _globals['_CHANGEDETAILS_UPLOADER_METADATAENTRY']._serialized_start=1625
  _globals['_CHANGEDETAILS_UPLOADER_METADATAENTRY']._serialized_end=1708
  _globals['_FILEOP']._serialized_start=1927
  _globals['_FILEOP']._serialized_end=2041
  _globals['_MODIFYFILESREQUEST']._serialized_start=2044
  _globals['_MODIFYFILESREQUEST']._serialized_end=2458
  _globals['_MODIFYFILESREQUEST_CONDITION']._serialized_start=2348
  _globals['_MODIFYFILESREQUEST_CONDITION']._serialized_end=2425
  _globals['_FILEERROR']._serialized_start=2461
  _globals['_FILEERROR']._serialized_end=2770
  _globals['_FILEERROR_CAUSE']._serialized_start=2583
  _globals['_FILEERROR_CAUSE']._serialized_end=2770
  _globals['_MODIFYFILESRESPONSE']._serialized_start=2772
  _globals['_MODIFYFILESRESPONSE']._serialized_end=2837
  _globals['_REPLACEFILESREQUEST']._serialized_start=2840
  _globals['_REPLACEFILESREQUEST']._serialized_end=3483
  _globals['_REPLACEFILESREQUEST_CONDITION']._serialized_start=2348
  _globals['_REPLACEFILESREQUEST_CONDITION']._serialized_end=2425
  _globals['_REPLACEFILESREQUEST_FILES']._serialized_start=3282
  _globals['_REPLACEFILESREQUEST_FILES']._serialized_end=3431
  _globals['_ERRDETAILVALIDATIONFAILURE']._serialized_start=3485
  _globals['_ERRDETAILVALIDATIONFAILURE']._serialized_end=3571
  _globals['_ERRDETAILNOUSABLEFILES']._serialized_start=3573
  _globals['_ERRDETAILNOUSABLEFILES']._serialized_end=3634
  _globals['_ERRDETAILCONDITIONUNSATISFIED']._serialized_start=3636
  _globals['_ERRDETAILCONDITIONUNSATISFIED']._serialized_end=3719
  _globals['_ERRDETAILOPERATIONDISCARDED']._serialized_start=3721
  _globals['_ERRDETAILOPERATIONDISCARDED']._serialized_end=3839
  _globals['_ERRDETAILCANNOTMODIFYGITCONNECTEDSTORE']._serialized_start=3841
  _globals['_ERRDETAILCANNOTMODIFYGITCONNECTEDSTORE']._serialized_end=3881
  _globals['_REPLACEFILESRESPONSE']._serialized_start=3883
  _globals['_REPLACEFILESRESPONSE']._serialized_end=3986
  _globals['_CERBOSSTORESERVICE']._serialized_start=3989
  _globals['_CERBOSSTORESERVICE']._serialized_end=4441
# @@protoc_insertion_point(module_scope)



# Copyright 2021-2025 Zenauth Ltd.
# SPDX-License-Identifier: Apache-2.0
import os
import threading
from datetime import datetime, timedelta
from typing import Optional

import grpc
from google.rpc import code_pb2
from grpc_status import rpc_status

from cerbos.cloud.apikey.v1 import apikey_pb2, apikey_pb2_grpc
from cerbos.sdk.hub.model import Credentials


class InvalidCredentialsError(Exception):
    pass


class _AuthClient:
    _EARLY_EXPIRY: timedelta = timedelta(minutes=5)
    _client: apikey_pb2_grpc.ApiKeyServiceStub
    _client_id: str
    _client_secret: str
    _timeout_secs: float
    _expiry: datetime
    _lock: threading.Lock
    _token: Optional[str] = None
    _invalid_credentials: bool = False

    def __init__(
        self,
        channel: grpc.Channel,
        timeout_secs: float,
        credentials: Optional[Credentials] = None,
    ):
        self._client_id = os.environ["CERBOS_HUB_CLIENT_ID"]
        self._client_secret = os.environ["CERBOS_HUB_CLIENT_SECRET"]
        if credentials:
            if credentials.client_id != "":
                self._client_id = credentials.client_id
            if credentials.client_secret != "":
                self._client_secret = credentials.client_secret
        self._client = apikey_pb2_grpc.ApiKeyServiceStub(channel)
        self._timeout_secs = timeout_secs
        self._lock = threading.Lock()

    def authenticate(self) -> str:
        with self._lock:
            if self._invalid_credentials:
                raise InvalidCredentialsError("Invalid credentials")
            if self._token and self._expiry > datetime.now():
                return self._token
            req = apikey_pb2.IssueAccessTokenRequest(
                client_id=self._client_id, client_secret=self._client_secret
            )
            try:
                resp: apikey_pb2.IssueAccessTokenResponse = (
                    self._client.IssueAccessToken(req, timeout=self._timeout_secs)
                )
                self._token = resp.access_token
                expires_in = resp.expires_in.ToTimedelta()
                if expires_in > self._EARLY_EXPIRY:
                    expires_in = expires_in - self._EARLY_EXPIRY
                self._expiry = datetime.now() + expires_in
                return self._token
            except grpc.RpcError as rpc_error:
                status = rpc_status.from_call(rpc_error)
                if status and status.code == code_pb2.UNAUTHENTICATED:
                    self._invalid_credentials = True
                    raise InvalidCredentialsError("Invalid credentials")
                raise rpc_error



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cerbos/cloud/pdp/v1/pdp.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cerbos/cloud/pdp/v1/pdp.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x63\x65rbos/cloud/pdp/v1/pdp.proto\x12\x13\x63\x65rbos.cloud.pdp.v1\x1a\x1b\x62uf/validate/validate.proto\"T\n\nIdentifier\x12#\n\x08instance\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x08instance\x12!\n\x07version\x18\x02 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x07versionBt\n\x1b\x64\x65v.cerbos.api.cloud.v1.pdpZ;github.com/cerbos/cloud-api/genpb/cerbos/cloud/pdp/v1;pdpv1\xaa\x02\x17\x43\x65rbos.Api.Cloud.V1.Pdpb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cerbos.cloud.pdp.v1.pdp_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033dev.cerbos.api.cloud.v1.pdpZ;github.com/cerbos/cloud-api/genpb/cerbos/cloud/pdp/v1;pdpv1\252\002\027Cerbos.Api.Cloud.V1.Pdp'
  _globals['_IDENTIFIER'].fields_by_name['instance']._loaded_options = None
  _globals['_IDENTIFIER'].fields_by_name['instance']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_IDENTIFIER'].fields_by_name['version']._loaded_options = None
  _globals['_IDENTIFIER'].fields_by_name['version']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_IDENTIFIER']._serialized_start=83
  _globals['_IDENTIFIER']._serialized_end=167
# @@protoc_insertion_point(module_scope)



# Copyright 2021-2025 Zenauth Ltd.
# SPDX-License-Identifier: Apache-2.0

from cerbos.sdk._async._hub._store import AsyncCerbosHubStoreClient
from cerbos.sdk._sync._hub._store import CerbosHubStoreClient

__all__ = [
    "AsyncCerbosHubStoreClient",
    "CerbosHubStoreClient",
]



# Copyright 2021-2025 Zenauth Ltd.
# SPDX-License-Identifier: Apache-2.0

import base64
from dataclasses import dataclass
from typing import Union

from cerbos.effect.v1.effect_pb2 import EFFECT_ALLOW
from cerbos.response.v1.response_pb2 import CheckResourcesResponse


@dataclass
class AdminCredentials:
    username: str = "cerbos"
    password: str = "cerbosAdmin"

    def metadata(self):
        credentials = f"{self.username}:{self.password}"
        encoded_credentials = base64.b64encode(credentials.encode("utf-8")).decode(
            "utf-8"
        )
        return (("authorization", f"Basic {encoded_credentials}"),)


def get_resource(
    resp: CheckResourcesResponse,
    resource_id: str,
    predicate=lambda _: True,
) -> Union[CheckResourcesResponse.ResultEntry, None]:
    return next(
        filter(
            lambda r: (r.resource.id == resource_id and predicate(r.resource)),
            resp.results,
        ),
        None,
    )


def is_allowed(entry: CheckResourcesResponse.ResultEntry, action: str) -> bool:
    if action in entry.actions:
        return entry.actions[action] == EFFECT_ALLOW
    return False



# Copyright 2021-2025 Zenauth Ltd.
# SPDX-License-Identifier: Apache-2.0
from typing import Any, Callable, List, NamedTuple, Optional

import grpc

from cerbos.sdk._sync._hub._auth import _AuthClient

# grpc.aio classes are annoyingly different from the non-async version so we need a second, slightly-different non-async implementation.


class _ClientCallDetails(NamedTuple):
    method: str
    timeout: Optional[float]
    metadata: Optional[List]
    credentials: Optional[grpc.CallCredentials]
    wait_for_ready: Optional[bool]
    compression: Optional[grpc.Compression]


# Dummy placeholder so that the non-async interceptor type-checks.


class _ClientCallDetailsWrapper(_ClientCallDetails, grpc.ClientCallDetails):
    pass


# Dummy placeholder so that the non-async interceptor type-checks.


class _AuthInterceptor(
    grpc.UnaryUnaryClientInterceptor,
    grpc.UnaryStreamClientInterceptor,
    grpc.StreamUnaryClientInterceptor,
    grpc.StreamStreamClientInterceptor,
):
    _auth_client: _AuthClient

    def __init__(self, auth_client: _AuthClient):
        self._auth_client = auth_client

    def _intercept(
        self,
        continuation: Callable[..., Any],
        client_call_details: grpc.ClientCallDetails,
        request: Any,
    ):
        token = self._auth_client.authenticate()
        metadata = client_call_details.metadata or []
        metadata.append(("x-cerbos-auth", token))
        new_client_call_details = _ClientCallDetailsWrapper(
            client_call_details.method,
            client_call_details.timeout,
            metadata,
            client_call_details.credentials,
            client_call_details.wait_for_ready,
            client_call_details.compression,
        )
        return continuation(new_client_call_details, request)

    def intercept_unary_unary(self, continuation, client_call_details, request):
        return self._intercept(continuation, client_call_details, request)

    def intercept_unary_stream(self, continuation, client_call_details, request):
        return self._intercept(continuation, client_call_details, request)

    def intercept_stream_unary(
        self, continuation, client_call_details, request_iterator
    ):
        return self._intercept(continuation, client_call_details, request_iterator)

    def intercept_stream_stream(
        self, continuation, client_call_details, request_iterator
    ):
        return self._intercept(continuation, client_call_details, request_iterator)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cerbos/policy/v1/policy.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cerbos/policy/v1/policy.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from cerbos.effect.v1 import effect_pb2 as cerbos_dot_effect_dot_v1_dot_effect__pb2
from cerbos.engine.v1 import engine_pb2 as cerbos_dot_engine_dot_v1_dot_engine__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x63\x65rbos/policy/v1/policy.proto\x12\x10\x63\x65rbos.policy.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1d\x63\x65rbos/effect/v1/effect.proto\x1a\x1d\x63\x65rbos/engine/v1/engine.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\xbe\x06\n\x06Policy\x12<\n\x0b\x61pi_version\x18\x01 \x01(\tB\x1b\xbaH\x18r\x13\n\x11\x61pi.cerbos.dev/v1\xc8\x01\x01R\napiVersion\x12\x1a\n\x08\x64isabled\x18\x02 \x01(\x08R\x08\x64isabled\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12\x36\n\x08metadata\x18\x04 \x01(\x0b\x32\x1a.cerbos.policy.v1.MetadataR\x08metadata\x12K\n\x0fresource_policy\x18\x05 \x01(\x0b\x32 .cerbos.policy.v1.ResourcePolicyH\x00R\x0eresourcePolicy\x12N\n\x10principal_policy\x18\x06 \x01(\x0b\x32!.cerbos.policy.v1.PrincipalPolicyH\x00R\x0fprincipalPolicy\x12\x45\n\rderived_roles\x18\x07 \x01(\x0b\x32\x1e.cerbos.policy.v1.DerivedRolesH\x00R\x0c\x64\x65rivedRoles\x12N\n\x10\x65xport_variables\x18\n \x01(\x0b\x32!.cerbos.policy.v1.ExportVariablesH\x00R\x0f\x65xportVariables\x12?\n\x0brole_policy\x18\x0b \x01(\x0b\x32\x1c.cerbos.policy.v1.RolePolicyH\x00R\nrolePolicy\x12N\n\x10\x65xport_constants\x18\x0c \x01(\x0b\x32!.cerbos.policy.v1.ExportConstantsH\x00R\x0f\x65xportConstants\x12I\n\tvariables\x18\x08 \x03(\x0b\x32\'.cerbos.policy.v1.Policy.VariablesEntryB\x02\x18\x01R\tvariables\x12\x1c\n\x0bjson_schema\x18\t \x01(\tR\x07$schema\x1a<\n\x0eVariablesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x14\n\x0bpolicy_type\x12\x05\xbaH\x02\x08\x01\"\xbd\x01\n\x10SourceAttributes\x12R\n\nattributes\x18\x01 \x03(\x0b\x32\x32.cerbos.policy.v1.SourceAttributes.AttributesEntryR\nattributes\x1aU\n\x0f\x41ttributesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.ValueR\x05value:\x02\x38\x01\"\x95\x03\n\x08Metadata\x12\x1f\n\x0bsource_file\x18\x01 \x01(\tR\nsourceFile\x12M\n\x0b\x61nnotations\x18\x02 \x03(\x0b\x32+.cerbos.policy.v1.Metadata.AnnotationsEntryR\x0b\x61nnotations\x12\x30\n\x04hash\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt64ValueR\x04hash\x12+\n\x0fstore_identifer\x18\x04 \x01(\tB\x02\x18\x01R\x0estoreIdentifer\x12)\n\x10store_identifier\x18\x05 \x01(\tR\x0fstoreIdentifier\x12O\n\x11source_attributes\x18\x06 \x01(\x0b\x32\".cerbos.policy.v1.SourceAttributesR\x10sourceAttributes\x1a>\n\x10\x41nnotationsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xbe\x04\n\x0eResourcePolicy\x12&\n\x08resource\x18\x01 \x01(\tB\n\xbaH\x07r\x02\x10\x01\xc8\x01\x01R\x08resource\x12\x31\n\x07version\x18\x02 \x01(\tB\x17\xbaH\x14r\x0f\x32\r^[[:word:]]+$\xc8\x01\x01R\x07version\x12Q\n\x14import_derived_roles\x18\x03 \x03(\tB\x1f\xbaH\x1c\x92\x01\x19\x18\x01\"\x15r\x13\x32\x11^[[:word:]\\-\\.]+$R\x12importDerivedRoles\x12\x34\n\x05rules\x18\x04 \x03(\x0b\x32\x1e.cerbos.policy.v1.ResourceRuleR\x05rules\x12L\n\x05scope\x18\x05 \x01(\tB6\xbaH3r12/^([[:alnum:]][[:word:]\\-]*(\\.[[:word:]\\-]*)*)*$R\x05scope\x12\x33\n\x07schemas\x18\x06 \x01(\x0b\x32\x19.cerbos.policy.v1.SchemasR\x07schemas\x12\x39\n\tvariables\x18\x07 \x01(\x0b\x32\x1b.cerbos.policy.v1.VariablesR\tvariables\x12O\n\x11scope_permissions\x18\x08 \x01(\x0e\x32\".cerbos.policy.v1.ScopePermissionsR\x10scopePermissions\x12\x39\n\tconstants\x18\t \x01(\x0b\x32\x1b.cerbos.policy.v1.ConstantsR\tconstants\"\x95\x03\n\x0cResourceRule\x12-\n\x07\x61\x63tions\x18\x01 \x03(\tB\x13\xbaH\x10\x92\x01\n\x08\x01\x18\x01\"\x04r\x02\x10\x01\xc8\x01\x01R\x07\x61\x63tions\x12\x44\n\rderived_roles\x18\x02 \x03(\tB\x1f\xbaH\x1c\x92\x01\x19\x18\x01\"\x15r\x13\x32\x11^[[:word:]\\-\\.]+$R\x0c\x64\x65rivedRoles\x12$\n\x05roles\x18\x03 \x03(\tB\x0e\xbaH\x0b\x92\x01\x08\x18\x01\"\x04r\x02\x10\x01R\x05roles\x12\x39\n\tcondition\x18\x04 \x01(\x0b\x32\x1b.cerbos.policy.v1.ConditionR\tcondition\x12?\n\x06\x65\x66\x66\x65\x63t\x18\x05 \x01(\x0e\x32\x18.cerbos.effect.v1.EffectB\r\xbaH\n\x82\x01\x04\x18\x01\x18\x02\xc8\x01\x01R\x06\x65\x66\x66\x65\x63t\x12<\n\x04name\x18\x06 \x01(\tB(\xbaH%r#2!^([[:alpha:]][[:word:]\\@\\.\\-]*)*$R\x04name\x12\x30\n\x06output\x18\x07 \x01(\x0b\x32\x18.cerbos.policy.v1.OutputR\x06output\"\xd3\x02\n\nRolePolicy\x12\x1d\n\x04role\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01H\x00R\x04role\x12\x31\n\x0cparent_roles\x18\x05 \x03(\tB\x0e\xbaH\x0b\x92\x01\x08\x18\x01\"\x04r\x02\x10\x01R\x0bparentRoles\x12L\n\x05scope\x18\x02 \x01(\tB6\xbaH3r12/^([[:alnum:]][[:word:]\\-]*(\\.[[:word:]\\-]*)*)*$R\x05scope\x12\x30\n\x05rules\x18\x03 \x03(\x0b\x32\x1a.cerbos.policy.v1.RoleRuleR\x05rules\x12]\n\x11scope_permissions\x18\x04 \x01(\x0e\x32\".cerbos.policy.v1.ScopePermissionsB\x0c\x18\x01\xbaH\x07\x82\x01\x04\x18\x00\x18\x02R\x10scopePermissionsB\x14\n\x0bpolicy_type\x12\x05\xbaH\x02\x08\x01\"\xa7\x01\n\x08RoleRule\x12&\n\x08resource\x18\x01 \x01(\tB\n\xbaH\x07r\x02\x10\x01\xc8\x01\x01R\x08resource\x12\x38\n\rallow_actions\x18\x02 \x03(\tB\x13\xbaH\x10\x92\x01\n\x08\x01\x18\x01\"\x04r\x02\x10\x01\xc8\x01\x01R\x0c\x61llowActions\x12\x39\n\tcondition\x18\x03 \x01(\x0b\x32\x1b.cerbos.policy.v1.ConditionR\tcondition\"\xba\x03\n\x0fPrincipalPolicy\x12(\n\tprincipal\x18\x01 \x01(\tB\n\xbaH\x07r\x02\x10\x01\xc8\x01\x01R\tprincipal\x12\x31\n\x07version\x18\x02 \x01(\tB\x17\xbaH\x14r\x0f\x32\r^[[:word:]]+$\xc8\x01\x01R\x07version\x12\x35\n\x05rules\x18\x03 \x03(\x0b\x32\x1f.cerbos.policy.v1.PrincipalRuleR\x05rules\x12L\n\x05scope\x18\x04 \x01(\tB6\xbaH3r12/^([[:alnum:]][[:word:]\\-]*(\\.[[:word:]\\-]*)*)*$R\x05scope\x12\x39\n\tvariables\x18\x05 \x01(\x0b\x32\x1b.cerbos.policy.v1.VariablesR\tvariables\x12O\n\x11scope_permissions\x18\x06 \x01(\x0e\x32\".cerbos.policy.v1.ScopePermissionsR\x10scopePermissions\x12\x39\n\tconstants\x18\x07 \x01(\x0b\x32\x1b.cerbos.policy.v1.ConstantsR\tconstants\"\xa1\x03\n\rPrincipalRule\x12&\n\x08resource\x18\x01 \x01(\tB\n\xbaH\x07r\x02\x10\x01\xc8\x01\x01R\x08resource\x12M\n\x07\x61\x63tions\x18\x02 \x03(\x0b\x32&.cerbos.policy.v1.PrincipalRule.ActionB\x0b\xbaH\x08\x92\x01\x02\x08\x01\xc8\x01\x01R\x07\x61\x63tions\x1a\x98\x02\n\x06\x41\x63tion\x12\"\n\x06\x61\x63tion\x18\x01 \x01(\tB\n\xbaH\x07r\x02\x10\x01\xc8\x01\x01R\x06\x61\x63tion\x12\x39\n\tcondition\x18\x02 \x01(\x0b\x32\x1b.cerbos.policy.v1.ConditionR\tcondition\x12?\n\x06\x65\x66\x66\x65\x63t\x18\x03 \x01(\x0e\x32\x18.cerbos.effect.v1.EffectB\r\xbaH\n\x82\x01\x04\x18\x01\x18\x02\xc8\x01\x01R\x06\x65\x66\x66\x65\x63t\x12<\n\x04name\x18\x04 \x01(\tB(\xbaH%r#2!^([[:alpha:]][[:word:]\\@\\.\\-]*)*$R\x04name\x12\x30\n\x06output\x18\x05 \x01(\x0b\x32\x18.cerbos.policy.v1.OutputR\x06output\"\x81\x02\n\x0c\x44\x65rivedRoles\x12\x31\n\x04name\x18\x01 \x01(\tB\x1d\xbaH\x1ar\x15\x10\x01\x32\x11^[[:word:]\\-\\.]+$\xc8\x01\x01R\x04name\x12H\n\x0b\x64\x65\x66initions\x18\x02 \x03(\x0b\x32\x19.cerbos.policy.v1.RoleDefB\x0b\xbaH\x08\x92\x01\x02\x08\x01\xc8\x01\x01R\x0b\x64\x65\x66initions\x12\x39\n\tvariables\x18\x03 \x01(\x0b\x32\x1b.cerbos.policy.v1.VariablesR\tvariables\x12\x39\n\tconstants\x18\x04 \x01(\x0b\x32\x1b.cerbos.policy.v1.ConstantsR\tconstants\"\xad\x01\n\x07RoleDef\x12/\n\x04name\x18\x01 \x01(\tB\x1b\xbaH\x18r\x13\x32\x11^[[:word:]\\-\\.]+$\xc8\x01\x01R\x04name\x12\x36\n\x0cparent_roles\x18\x02 \x03(\tB\x13\xbaH\x10\x92\x01\n\x08\x01\x18\x01\"\x04r\x02\x10\x01\xc8\x01\x01R\x0bparentRoles\x12\x39\n\tcondition\x18\x03 \x01(\x0b\x32\x1b.cerbos.policy.v1.ConditionR\tcondition\"\xf2\x01\n\x0f\x45xportConstants\x12\x31\n\x04name\x18\x01 \x01(\tB\x1d\xbaH\x1ar\x15\x10\x01\x32\x11^[[:word:]\\-\\.]+$\xc8\x01\x01R\x04name\x12T\n\x0b\x64\x65\x66initions\x18\x02 \x03(\x0b\x32\x32.cerbos.policy.v1.ExportConstants.DefinitionsEntryR\x0b\x64\x65\x66initions\x1aV\n\x10\x44\x65\x66initionsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.ValueR\x05value:\x02\x38\x01\"\xd4\x01\n\tConstants\x12\x37\n\x06import\x18\x01 \x03(\tB\x1f\xbaH\x1c\x92\x01\x19\x18\x01\"\x15r\x13\x32\x11^[[:word:]\\-\\.]+$R\x06import\x12<\n\x05local\x18\x02 \x03(\x0b\x32&.cerbos.policy.v1.Constants.LocalEntryR\x05local\x1aP\n\nLocalEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.ValueR\x05value:\x02\x38\x01\"\xda\x01\n\x0f\x45xportVariables\x12\x31\n\x04name\x18\x01 \x01(\tB\x1d\xbaH\x1ar\x15\x10\x01\x32\x11^[[:word:]\\-\\.]+$\xc8\x01\x01R\x04name\x12T\n\x0b\x64\x65\x66initions\x18\x02 \x03(\x0b\x32\x32.cerbos.policy.v1.ExportVariables.DefinitionsEntryR\x0b\x64\x65\x66initions\x1a>\n\x10\x44\x65\x66initionsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xbc\x01\n\tVariables\x12\x37\n\x06import\x18\x01 \x03(\tB\x1f\xbaH\x1c\x92\x01\x19\x18\x01\"\x15r\x13\x32\x11^[[:word:]\\-\\.]+$R\x06import\x12<\n\x05local\x18\x02 \x03(\x0b\x32&.cerbos.policy.v1.Variables.LocalEntryR\x05local\x1a\x38\n\nLocalEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"j\n\tCondition\x12/\n\x05match\x18\x01 \x01(\x0b\x32\x17.cerbos.policy.v1.MatchH\x00R\x05match\x12\x18\n\x06script\x18\x02 \x01(\tH\x00R\x06scriptB\x12\n\tcondition\x12\x05\xbaH\x02\x08\x01\"\x90\x02\n\x05Match\x12\x34\n\x03\x61ll\x18\x01 \x01(\x0b\x32 .cerbos.policy.v1.Match.ExprListH\x00R\x03\x61ll\x12\x34\n\x03\x61ny\x18\x02 \x01(\x0b\x32 .cerbos.policy.v1.Match.ExprListH\x00R\x03\x61ny\x12\x36\n\x04none\x18\x03 \x01(\x0b\x32 .cerbos.policy.v1.Match.ExprListH\x00R\x04none\x12\x14\n\x04\x65xpr\x18\x04 \x01(\tH\x00R\x04\x65xpr\x1a@\n\x08\x45xprList\x12\x34\n\x02of\x18\x01 \x03(\x0b\x32\x17.cerbos.policy.v1.MatchB\x0b\xbaH\x08\x92\x01\x02\x08\x01\xc8\x01\x01R\x02ofB\x0b\n\x02op\x12\x05\xbaH\x02\x08\x01\"\xae\x01\n\x06Output\x12\x16\n\x04\x65xpr\x18\x01 \x01(\tB\x02\x18\x01R\x04\x65xpr\x12\x31\n\x04when\x18\x02 \x01(\x0b\x32\x1d.cerbos.policy.v1.Output.WhenR\x04when\x1aY\n\x04When\x12%\n\x0erule_activated\x18\x01 \x01(\tR\rruleActivated\x12*\n\x11\x63ondition_not_met\x18\x02 \x01(\tR\x0f\x63onditionNotMet\"\xcd\x02\n\x07Schemas\x12K\n\x10principal_schema\x18\x01 \x01(\x0b\x32 .cerbos.policy.v1.Schemas.SchemaR\x0fprincipalSchema\x12I\n\x0fresource_schema\x18\x02 \x01(\x0b\x32 .cerbos.policy.v1.Schemas.SchemaR\x0eresourceSchema\x1a;\n\nIgnoreWhen\x12-\n\x07\x61\x63tions\x18\x01 \x03(\tB\x13\xbaH\x10\x92\x01\n\x08\x01\x18\x01\"\x04r\x02\x10\x01\xc8\x01\x01R\x07\x61\x63tions\x1am\n\x06Schema\x12\x1c\n\x03ref\x18\x01 \x01(\tB\n\xbaH\x07r\x02\x10\x01\xc8\x01\x01R\x03ref\x12\x45\n\x0bignore_when\x18\x02 \x01(\x0b\x32$.cerbos.policy.v1.Schemas.IgnoreWhenR\nignoreWhen\"\xd0\x08\n\x0bTestFixture\x1a\xbd\x03\n\nPrincipals\x12X\n\nprincipals\x18\x01 \x03(\x0b\x32\x38.cerbos.policy.v1.TestFixture.Principals.PrincipalsEntryR\nprincipals\x12\x1c\n\x0bjson_schema\x18\x02 \x01(\tR\x07$schema\x12h\n\x10principal_groups\x18\x03 \x03(\x0b\x32=.cerbos.policy.v1.TestFixture.Principals.PrincipalGroupsEntryR\x0fprincipalGroups\x1aZ\n\x0fPrincipalsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x31\n\x05value\x18\x02 \x01(\x0b\x32\x1b.cerbos.engine.v1.PrincipalR\x05value:\x02\x38\x01\x1aq\n\x14PrincipalGroupsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x43\n\x05value\x18\x02 \x01(\x0b\x32-.cerbos.policy.v1.TestFixtureGroup.PrincipalsR\x05value:\x02\x38\x01\x1a\xb0\x03\n\tResources\x12T\n\tresources\x18\x01 \x03(\x0b\x32\x36.cerbos.policy.v1.TestFixture.Resources.ResourcesEntryR\tresources\x12\x1c\n\x0bjson_schema\x18\x02 \x01(\tR\x07$schema\x12\x64\n\x0fresource_groups\x18\x03 \x03(\x0b\x32;.cerbos.policy.v1.TestFixture.Resources.ResourceGroupsEntryR\x0eresourceGroups\x1aX\n\x0eResourcesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.cerbos.engine.v1.ResourceR\x05value:\x02\x38\x01\x1ao\n\x13ResourceGroupsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x42\n\x05value\x18\x02 \x01(\x0b\x32,.cerbos.policy.v1.TestFixtureGroup.ResourcesR\x05value:\x02\x38\x01\x1a\xcd\x01\n\x07\x41uxData\x12M\n\x08\x61ux_data\x18\x01 \x03(\x0b\x32\x32.cerbos.policy.v1.TestFixture.AuxData.AuxDataEntryR\x07\x61uxData\x12\x1c\n\x0bjson_schema\x18\x02 \x01(\tR\x07$schema\x1aU\n\x0c\x41uxDataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12/\n\x05value\x18\x02 \x01(\x0b\x32\x19.cerbos.engine.v1.AuxDataR\x05value:\x02\x38\x01\"\x95\x01\n\x10TestFixtureGroup\x1a\x41\n\nPrincipals\x12\x33\n\nprincipals\x18\x01 \x03(\tB\x13\xbaH\x10\x92\x01\n\x08\x01\x18\x01\"\x04r\x02\x10\x01\xc8\x01\x01R\nprincipals\x1a>\n\tResources\x12\x31\n\tresources\x18\x01 \x03(\tB\x13\xbaH\x10\x92\x01\n\x08\x01\x18\x01\"\x04r\x02\x10\x01\xc8\x01\x01R\tresources\"\xbd\x02\n\x0bTestOptions\x12,\n\x03now\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x03now\x12\x30\n\x14lenient_scope_search\x18\x02 \x01(\x08R\x12lenientScopeSearch\x12\x44\n\x07globals\x18\x03 \x03(\x0b\x32*.cerbos.policy.v1.TestOptions.GlobalsEntryR\x07globals\x12\x34\n\x16\x64\x65\x66\x61ult_policy_version\x18\x04 \x01(\tR\x14\x64\x65\x66\x61ultPolicyVersion\x1aR\n\x0cGlobalsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.ValueR\x05value:\x02\x38\x01\"\x9d\t\n\tTestSuite\x12\x1e\n\x04name\x18\x01 \x01(\tB\n\xbaH\x07r\x02\x10\x01\xc8\x01\x01R\x04name\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12\x12\n\x04skip\x18\x03 \x01(\x08R\x04skip\x12\x1f\n\x0bskip_reason\x18\x04 \x01(\tR\nskipReason\x12>\n\x05tests\x18\x05 \x03(\x0b\x32\x1b.cerbos.policy.v1.TestTableB\x0b\xbaH\x08\x92\x01\x02\x08\x01\xc8\x01\x01R\x05tests\x12K\n\nprincipals\x18\x06 \x03(\x0b\x32+.cerbos.policy.v1.TestSuite.PrincipalsEntryR\nprincipals\x12H\n\tresources\x18\x07 \x03(\x0b\x32*.cerbos.policy.v1.TestSuite.ResourcesEntryR\tresources\x12\x43\n\x08\x61ux_data\x18\x08 \x03(\x0b\x32(.cerbos.policy.v1.TestSuite.AuxDataEntryR\x07\x61uxData\x12\x37\n\x07options\x18\t \x01(\x0b\x32\x1d.cerbos.policy.v1.TestOptionsR\x07options\x12\x1c\n\x0bjson_schema\x18\n \x01(\tR\x07$schema\x12[\n\x10principal_groups\x18\x0b \x03(\x0b\x32\x30.cerbos.policy.v1.TestSuite.PrincipalGroupsEntryR\x0fprincipalGroups\x12X\n\x0fresource_groups\x18\x0c \x03(\x0b\x32/.cerbos.policy.v1.TestSuite.ResourceGroupsEntryR\x0eresourceGroups\x1aZ\n\x0fPrincipalsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x31\n\x05value\x18\x02 \x01(\x0b\x32\x1b.cerbos.engine.v1.PrincipalR\x05value:\x02\x38\x01\x1aX\n\x0eResourcesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.cerbos.engine.v1.ResourceR\x05value:\x02\x38\x01\x1aU\n\x0c\x41uxDataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12/\n\x05value\x18\x02 \x01(\x0b\x32\x19.cerbos.engine.v1.AuxDataR\x05value:\x02\x38\x01\x1aq\n\x14PrincipalGroupsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x43\n\x05value\x18\x02 \x01(\x0b\x32-.cerbos.policy.v1.TestFixtureGroup.PrincipalsR\x05value:\x02\x38\x01\x1ao\n\x13ResourceGroupsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x42\n\x05value\x18\x02 \x01(\x0b\x32,.cerbos.policy.v1.TestFixtureGroup.ResourcesR\x05value:\x02\x38\x01\"\x99\x11\n\tTestTable\x12\x1e\n\x04name\x18\x01 \x01(\tB\n\xbaH\x07r\x02\x10\x01\xc8\x01\x01R\x04name\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12\x12\n\x04skip\x18\x03 \x01(\x08R\x04skip\x12\x1f\n\x0bskip_reason\x18\x04 \x01(\tR\nskipReason\x12?\n\x05input\x18\x05 \x01(\x0b\x32!.cerbos.policy.v1.TestTable.InputB\x06\xbaH\x03\xc8\x01\x01R\x05input\x12P\n\x08\x65xpected\x18\x06 \x03(\x0b\x32\'.cerbos.policy.v1.TestTable.ExpectationB\x0b\xbaH\x08\x92\x01\x02\x08\x01\xc8\x01\x01R\x08\x65xpected\x12\x37\n\x07options\x18\x07 \x01(\x0b\x32\x1d.cerbos.policy.v1.TestOptionsR\x07options\x1a\xa7\x04\n\x05Input\x12.\n\nprincipals\x18\x01 \x03(\tB\x0e\xbaH\x0b\x92\x01\x08\x18\x01\"\x04r\x02\x10\x01R\nprincipals\x12,\n\tresources\x18\x02 \x03(\tB\x0e\xbaH\x0b\x92\x01\x08\x18\x01\"\x04r\x02\x10\x01R\tresources\x12-\n\x07\x61\x63tions\x18\x03 \x03(\tB\x13\xbaH\x10\x92\x01\n\x08\x01\x18\x01\"\x04r\x02\x10\x01\xc8\x01\x01R\x07\x61\x63tions\x12\x19\n\x08\x61ux_data\x18\x04 \x01(\tR\x07\x61uxData\x12\x39\n\x10principal_groups\x18\x05 \x03(\tB\x0e\xbaH\x0b\x92\x01\x08\x18\x01\"\x04r\x02\x10\x01R\x0fprincipalGroups\x12\x37\n\x0fresource_groups\x18\x06 \x03(\tB\x0e\xbaH\x0b\x92\x01\x08\x18\x01\"\x04r\x02\x10\x01R\x0eresourceGroups:\x81\x02\xbaH\xfd\x01\x1a\x7f\n\x10input.principals\x12-principals or principalGroups must be present\x1a<size(this.principals) > 0 || size(this.principal_groups) > 0\x1az\n\x0finput.resources\x12+resources or resourceGroups must be present\x1a:size(this.resources) > 0 || size(this.resource_groups) > 0\x1a\x80\x01\n\x12OutputExpectations\x12\"\n\x06\x61\x63tion\x18\x01 \x01(\tB\n\xbaH\x07r\x02\x10\x01\xc8\x01\x01R\x06\x61\x63tion\x12\x46\n\x08\x65xpected\x18\x02 \x03(\x0b\x32\x1d.cerbos.engine.v1.OutputEntryB\x0b\xbaH\x08\x92\x01\x02\x08\x01\xc8\x01\x01R\x08\x65xpected\x1a\x9b\t\n\x0b\x45xpectation\x12\x1c\n\tprincipal\x18\x01 \x01(\tR\tprincipal\x12\x1a\n\x08resource\x18\x02 \x01(\tR\x08resource\x12j\n\x07\x61\x63tions\x18\x03 \x03(\x0b\x32\x34.cerbos.policy.v1.TestTable.Expectation.ActionsEntryB\x1a\xbaH\x17\x9a\x01\x11\x08\x01\"\x04r\x02\x10\x01*\x07\x82\x01\x04\x18\x01\x18\x02\xc8\x01\x01R\x07\x61\x63tions\x12H\n\x07outputs\x18\x04 \x03(\x0b\x32..cerbos.policy.v1.TestTable.OutputExpectationsR\x07outputs\x12.\n\nprincipals\x18\x05 \x03(\tB\x0e\xbaH\x0b\x92\x01\x08\x18\x01\"\x04r\x02\x10\x01R\nprincipals\x12,\n\tresources\x18\x06 \x03(\tB\x0e\xbaH\x0b\x92\x01\x08\x18\x01\"\x04r\x02\x10\x01R\tresources\x12\x39\n\x10principal_groups\x18\x07 \x03(\tB\x0e\xbaH\x0b\x92\x01\x08\x18\x01\"\x04r\x02\x10\x01R\x0fprincipalGroups\x12\x37\n\x0fresource_groups\x18\x08 \x03(\tB\x0e\xbaH\x0b\x92\x01\x08\x18\x01\"\x04r\x02\x10\x01R\x0eresourceGroups\x1aT\n\x0c\x41\x63tionsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12.\n\x05value\x18\x02 \x01(\x0e\x32\x18.cerbos.effect.v1.EffectR\x05value:\x02\x38\x01:\xf3\x04\xbaH\xef\x04\x1a\xa9\x01\n\x16\x65xpectation.principals\x12\x39principal, principals, or principalGroups must be present\x1aTthis.principal != \'\' || size(this.principals) > 0 || size(this.principal_groups) > 0\x1a\x8f\x01\n%expectation.principal_nand_principals\x12\x30principal and principals may not both be present\x1a\x34!(this.principal != \'\' && size(this.principals) > 0)\x1a\xa2\x01\n\x15\x65xpectation.resources\x12\x36resource, resources, or resourceGroups must be present\x1aQthis.resource != \'\' || size(this.resources) > 0 || size(this.resource_groups) > 0\x1a\x89\x01\n#expectation.resource_nand_resources\x12.resource and resources may not both be present\x1a\x32!(this.resource != \'\' && size(this.resources) > 0)\"\xda\x07\n\x04Test\x12;\n\x04name\x18\x01 \x01(\x0b\x32\x1f.cerbos.policy.v1.Test.TestNameB\x06\xbaH\x03\xc8\x01\x01R\x04name\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12\x12\n\x04skip\x18\x03 \x01(\x08R\x04skip\x12\x1f\n\x0bskip_reason\x18\x04 \x01(\tR\nskipReason\x12:\n\x05input\x18\x05 \x01(\x0b\x32\x1c.cerbos.engine.v1.CheckInputB\x06\xbaH\x03\xc8\x01\x01R\x05input\x12\\\n\x08\x65xpected\x18\x06 \x03(\x0b\x32$.cerbos.policy.v1.Test.ExpectedEntryB\x1a\xbaH\x17\x9a\x01\x11\x08\x01\"\x04r\x02\x10\x01*\x07\x82\x01\x04\x18\x01\x18\x02\xc8\x01\x01R\x08\x65xpected\x12\x37\n\x07options\x18\x07 \x01(\x0b\x32\x1d.cerbos.policy.v1.TestOptionsR\x07options\x12V\n\x10\x65xpected_outputs\x18\x08 \x03(\x0b\x32+.cerbos.policy.v1.Test.ExpectedOutputsEntryR\x0f\x65xpectedOutputs\x1a\x9e\x01\n\x08TestName\x12\x32\n\x0ftest_table_name\x18\x01 \x01(\tB\n\xbaH\x07r\x02\x10\x01\xc8\x01\x01R\rtestTableName\x12/\n\rprincipal_key\x18\x02 \x01(\tB\n\xbaH\x07r\x02\x10\x01\xc8\x01\x01R\x0cprincipalKey\x12-\n\x0cresource_key\x18\x03 \x01(\tB\n\xbaH\x07r\x02\x10\x01\xc8\x01\x01R\x0bresourceKey\x1a\xb0\x01\n\rOutputEntries\x12K\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x31.cerbos.policy.v1.Test.OutputEntries.EntriesEntryR\x07\x65ntries\x1aR\n\x0c\x45ntriesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.ValueR\x05value:\x02\x38\x01\x1aU\n\rExpectedEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12.\n\x05value\x18\x02 \x01(\x0e\x32\x18.cerbos.effect.v1.EffectR\x05value:\x02\x38\x01\x1ah\n\x14\x45xpectedOutputsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12:\n\x05value\x18\x02 \x01(\x0b\x32$.cerbos.policy.v1.Test.OutputEntriesR\x05value:\x02\x38\x01\"\xad\x12\n\x0bTestResults\x12;\n\x06suites\x18\x01 \x03(\x0b\x32#.cerbos.policy.v1.TestResults.SuiteR\x06suites\x12?\n\x07summary\x18\x02 \x01(\x0b\x32%.cerbos.policy.v1.TestResults.SummaryR\x07summary\x1a[\n\x05Tally\x12<\n\x06result\x18\x01 \x01(\x0e\x32$.cerbos.policy.v1.TestResults.ResultR\x06result\x12\x14\n\x05\x63ount\x18\x02 \x01(\rR\x05\x63ount\x1a\xc1\x01\n\x07Summary\x12K\n\x0eoverall_result\x18\x01 \x01(\x0e\x32$.cerbos.policy.v1.TestResults.ResultR\roverallResult\x12\x1f\n\x0btests_count\x18\x02 \x01(\rR\ntestsCount\x12H\n\rresult_counts\x18\x03 \x03(\x0b\x32#.cerbos.policy.v1.TestResults.TallyR\x0cresultCounts\x1a\xdd\x02\n\x05Suite\x12\x12\n\x04\x66ile\x18\x01 \x01(\tR\x04\x66ile\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12K\n\nprincipals\x18\x03 \x03(\x0b\x32\'.cerbos.policy.v1.TestResults.PrincipalB\x02\x18\x01R\nprincipals\x12?\n\x07summary\x18\x04 \x01(\x0b\x32%.cerbos.policy.v1.TestResults.SummaryR\x07summary\x12\x14\n\x05\x65rror\x18\x05 \x01(\tR\x05\x65rror\x12\x45\n\ntest_cases\x18\x06 \x03(\x0b\x32&.cerbos.policy.v1.TestResults.TestCaseR\ttestCases\x12 \n\x0b\x64\x65scription\x18\x07 \x01(\tR\x0b\x64\x65scription\x12\x1f\n\x0bskip_reason\x18\x08 \x01(\tR\nskipReason\x1ag\n\x08TestCase\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12G\n\nprincipals\x18\x02 \x03(\x0b\x32\'.cerbos.policy.v1.TestResults.PrincipalR\nprincipals\x1a\x65\n\tPrincipal\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x44\n\tresources\x18\x02 \x03(\x0b\x32&.cerbos.policy.v1.TestResults.ResourceR\tresources\x1a^\n\x08Resource\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12>\n\x07\x61\x63tions\x18\x02 \x03(\x0b\x32$.cerbos.policy.v1.TestResults.ActionR\x07\x61\x63tions\x1a]\n\x06\x41\x63tion\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12?\n\x07\x64\x65tails\x18\x02 \x01(\x0b\x32%.cerbos.policy.v1.TestResults.DetailsR\x07\x64\x65tails\x1a\xcf\x02\n\x07\x44\x65tails\x12<\n\x06result\x18\x01 \x01(\x0e\x32$.cerbos.policy.v1.TestResults.ResultR\x06result\x12\x41\n\x07\x66\x61ilure\x18\x02 \x01(\x0b\x32%.cerbos.policy.v1.TestResults.FailureH\x00R\x07\x66\x61ilure\x12\x16\n\x05\x65rror\x18\x03 \x01(\tH\x00R\x05\x65rror\x12\x41\n\x07success\x18\x05 \x01(\x0b\x32%.cerbos.policy.v1.TestResults.SuccessH\x00R\x07success\x12!\n\x0bskip_reason\x18\x06 \x01(\tH\x00R\nskipReason\x12:\n\x0c\x65ngine_trace\x18\x04 \x03(\x0b\x32\x17.cerbos.engine.v1.TraceR\x0b\x65ngineTraceB\t\n\x07outcome\x1a\x9c\x03\n\rOutputFailure\x12\x10\n\x03src\x18\x01 \x01(\tR\x03src\x12]\n\nmismatched\x18\x02 \x01(\x0b\x32;.cerbos.policy.v1.TestResults.OutputFailure.MismatchedValueH\x00R\nmismatched\x12T\n\x07missing\x18\x03 \x01(\x0b\x32\x38.cerbos.policy.v1.TestResults.OutputFailure.MissingValueH\x00R\x07missing\x1au\n\x0fMismatchedValue\x12\x32\n\x08\x65xpected\x18\x01 \x01(\x0b\x32\x16.google.protobuf.ValueR\x08\x65xpected\x12.\n\x06\x61\x63tual\x18\x02 \x01(\x0b\x32\x16.google.protobuf.ValueR\x06\x61\x63tual\x1a\x42\n\x0cMissingValue\x12\x32\n\x08\x65xpected\x18\x01 \x01(\x0b\x32\x16.google.protobuf.ValueR\x08\x65xpectedB\t\n\x07outcome\x1a\xb8\x01\n\x07\x46\x61ilure\x12\x34\n\x08\x65xpected\x18\x01 \x01(\x0e\x32\x18.cerbos.effect.v1.EffectR\x08\x65xpected\x12\x30\n\x06\x61\x63tual\x18\x02 \x01(\x0e\x32\x18.cerbos.effect.v1.EffectR\x06\x61\x63tual\x12\x45\n\x07outputs\x18\x03 \x03(\x0b\x32+.cerbos.policy.v1.TestResults.OutputFailureR\x07outputs\x1at\n\x07Success\x12\x30\n\x06\x65\x66\x66\x65\x63t\x18\x01 \x01(\x0e\x32\x18.cerbos.effect.v1.EffectR\x06\x65\x66\x66\x65\x63t\x12\x37\n\x07outputs\x18\x02 \x03(\x0b\x32\x1d.cerbos.engine.v1.OutputEntryR\x07outputs\"n\n\x06Result\x12\x16\n\x12RESULT_UNSPECIFIED\x10\x00\x12\x12\n\x0eRESULT_SKIPPED\x10\x01\x12\x11\n\rRESULT_PASSED\x10\x02\x12\x11\n\rRESULT_FAILED\x10\x03\x12\x12\n\x0eRESULT_ERRORED\x10\x04*\xa7\x01\n\x04Kind\x12\x14\n\x10KIND_UNSPECIFIED\x10\x00\x12\x16\n\x12KIND_DERIVED_ROLES\x10\x01\x12\x19\n\x15KIND_EXPORT_VARIABLES\x10\x02\x12\x12\n\x0eKIND_PRINCIPAL\x10\x03\x12\x11\n\rKIND_RESOURCE\x10\x04\x12\x14\n\x10KIND_ROLE_POLICY\x10\x05\x12\x19\n\x15KIND_EXPORT_CONSTANTS\x10\x06*\x97\x01\n\x10ScopePermissions\x12!\n\x1dSCOPE_PERMISSIONS_UNSPECIFIED\x10\x00\x12%\n!SCOPE_PERMISSIONS_OVERRIDE_PARENT\x10\x01\x12\x39\n5SCOPE_PERMISSIONS_REQUIRE_PARENTAL_CONSENT_FOR_ALLOWS\x10\x02\x42o\n\x18\x64\x65v.cerbos.api.v1.policyZ<github.com/cerbos/cerbos/api/genpb/cerbos/policy/v1;policyv1\xaa\x02\x14\x43\x65rbos.Api.V1.Policyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cerbos.policy.v1.policy_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\030dev.cerbos.api.v1.policyZ<github.com/cerbos/cerbos/api/genpb/cerbos/policy/v1;policyv1\252\002\024Cerbos.Api.V1.Policy'
  _globals['_POLICY_VARIABLESENTRY']._loaded_options = None
  _globals['_POLICY_VARIABLESENTRY']._serialized_options = b'8\001'
  _globals['_POLICY'].oneofs_by_name['policy_type']._loaded_options = None
  _globals['_POLICY'].oneofs_by_name['policy_type']._serialized_options = b'\272H\002\010\001'
  _globals['_POLICY'].fields_by_name['api_version']._loaded_options = None
  _globals['_POLICY'].fields_by_name['api_version']._serialized_options = b'\272H\030r\023\n\021api.cerbos.dev/v1\310\001\001'
  _globals['_POLICY'].fields_by_name['variables']._loaded_options = None
  _globals['_POLICY'].fields_by_name['variables']._serialized_options = b'\030\001'
  _globals['_SOURCEATTRIBUTES_ATTRIBUTESENTRY']._loaded_options = None
  _globals['_SOURCEATTRIBUTES_ATTRIBUTESENTRY']._serialized_options = b'8\001'
  _globals['_METADATA_ANNOTATIONSENTRY']._loaded_options = None
  _globals['_METADATA_ANNOTATIONSENTRY']._serialized_options = b'8\001'
  _globals['_METADATA'].fields_by_name['store_identifer']._loaded_options = None
  _globals['_METADATA'].fields_by_name['store_identifer']._serialized_options = b'\030\001'
  _globals['_RESOURCEPOLICY'].fields_by_name['resource']._loaded_options = None
  _globals['_RESOURCEPOLICY'].fields_by_name['resource']._serialized_options = b'\272H\007r\002\020\001\310\001\001'
  _globals['_RESOURCEPOLICY'].fields_by_name['version']._loaded_options = None
  _globals['_RESOURCEPOLICY'].fields_by_name['version']._serialized_options = b'\272H\024r\0172\r^[[:word:]]+$\310\001\001'
  _globals['_RESOURCEPOLICY'].fields_by_name['import_derived_roles']._loaded_options = None
  _globals['_RESOURCEPOLICY'].fields_by_name['import_derived_roles']._serialized_options = b'\272H\034\222\001\031\030\001\"\025r\0232\021^[[:word:]\\-\\.]+$'
  _globals['_RESOURCEPOLICY'].fields_by_name['scope']._loaded_options = None
  _globals['_RESOURCEPOLICY'].fields_by_name['scope']._serialized_options = b'\272H3r12/^([[:alnum:]][[:word:]\\-]*(\\.[[:word:]\\-]*)*)*$'
  _globals['_RESOURCERULE'].fields_by_name['actions']._loaded_options = None
  _globals['_RESOURCERULE'].fields_by_name['actions']._serialized_options = b'\272H\020\222\001\n\010\001\030\001\"\004r\002\020\001\310\001\001'
  _globals['_RESOURCERULE'].fields_by_name['derived_roles']._loaded_options = None
  _globals['_RESOURCERULE'].fields_by_name['derived_roles']._serialized_options = b'\272H\034\222\001\031\030\001\"\025r\0232\021^[[:word:]\\-\\.]+$'
  _globals['_RESOURCERULE'].fields_by_name['roles']._loaded_options = None
  _globals['_RESOURCERULE'].fields_by_name['roles']._serialized_options = b'\272H\013\222\001\010\030\001\"\004r\002\020\001'
  _globals['_RESOURCERULE'].fields_by_name['effect']._loaded_options = None
  _globals['_RESOURCERULE'].fields_by_name['effect']._serialized_options = b'\272H\n\202\001\004\030\001\030\002\310\001\001'
  _globals['_RESOURCERULE'].fields_by_name['name']._loaded_options = None
  _globals['_RESOURCERULE'].fields_by_name['name']._serialized_options = b'\272H%r#2!^([[:alpha:]][[:word:]\\@\\.\\-]*)*$'
  _globals['_ROLEPOLICY'].oneofs_by_name['policy_type']._loaded_options = None
  _globals['_ROLEPOLICY'].oneofs_by_name['policy_type']._serialized_options = b'\272H\002\010\001'
  _globals['_ROLEPOLICY'].fields_by_name['role']._loaded_options = None
  _globals['_ROLEPOLICY'].fields_by_name['role']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_ROLEPOLICY'].fields_by_name['parent_roles']._loaded_options = None
  _globals['_ROLEPOLICY'].fields_by_name['parent_roles']._serialized_options = b'\272H\013\222\001\010\030\001\"\004r\002\020\001'
  _globals['_ROLEPOLICY'].fields_by_name['scope']._loaded_options = None
  _globals['_ROLEPOLICY'].fields_by_name['scope']._serialized_options = b'\272H3r12/^([[:alnum:]][[:word:]\\-]*(\\.[[:word:]\\-]*)*)*$'
  _globals['_ROLEPOLICY'].fields_by_name['scope_permissions']._loaded_options = None
  _globals['_ROLEPOLICY'].fields_by_name['scope_permissions']._serialized_options = b'\030\001\272H\007\202\001\004\030\000\030\002'
  _globals['_ROLERULE'].fields_by_name['resource']._loaded_options = None
  _globals['_ROLERULE'].fields_by_name['resource']._serialized_options = b'\272H\007r\002\020\001\310\001\001'
  _globals['_ROLERULE'].fields_by_name['allow_actions']._loaded_options = None
  _globals['_ROLERULE'].fields_by_name['allow_actions']._serialized_options = b'\272H\020\222\001\n\010\001\030\001\"\004r\002\020\001\310\001\001'
  _globals['_PRINCIPALPOLICY'].fields_by_name['principal']._loaded_options = None
  _globals['_PRINCIPALPOLICY'].fields_by_name['principal']._serialized_options = b'\272H\007r\002\020\001\310\001\001'
  _globals['_PRINCIPALPOLICY'].fields_by_name['version']._loaded_options = None
  _globals['_PRINCIPALPOLICY'].fields_by_name['version']._serialized_options = b'\272H\024r\0172\r^[[:word:]]+$\310\001\001'
  _globals['_PRINCIPALPOLICY'].fields_by_name['scope']._loaded_options = None
  _globals['_PRINCIPALPOLICY'].fields_by_name['scope']._serialized_options = b'\272H3r12/^([[:alnum:]][[:word:]\\-]*(\\.[[:word:]\\-]*)*)*$'
  _globals['_PRINCIPALRULE_ACTION'].fields_by_name['action']._loaded_options = None
  _globals['_PRINCIPALRULE_ACTION'].fields_by_name['action']._serialized_options = b'\272H\007r\002\020\001\310\001\001'
  _globals['_PRINCIPALRULE_ACTION'].fields_by_name['effect']._loaded_options = None
  _globals['_PRINCIPALRULE_ACTION'].fields_by_name['effect']._serialized_options = b'\272H\n\202\001\004\030\001\030\002\310\001\001'
  _globals['_PRINCIPALRULE_ACTION'].fields_by_name['name']._loaded_options = None
  _globals['_PRINCIPALRULE_ACTION'].fields_by_name['name']._serialized_options = b'\272H%r#2!^([[:alpha:]][[:word:]\\@\\.\\-]*)*$'
  _globals['_PRINCIPALRULE'].fields_by_name['resource']._loaded_options = None
  _globals['_PRINCIPALRULE'].fields_by_name['resource']._serialized_options = b'\272H\007r\002\020\001\310\001\001'
  _globals['_PRINCIPALRULE'].fields_by_name['actions']._loaded_options = None
  _globals['_PRINCIPALRULE'].fields_by_name['actions']._serialized_options = b'\272H\010\222\001\002\010\001\310\001\001'
  _globals['_DERIVEDROLES'].fields_by_name['name']._loaded_options = None
  _globals['_DERIVEDROLES'].fields_by_name['name']._serialized_options = b'\272H\032r\025\020\0012\021^[[:word:]\\-\\.]+$\310\001\001'
  _globals['_DERIVEDROLES'].fields_by_name['definitions']._loaded_options = None
  _globals['_DERIVEDROLES'].fields_by_name['definitions']._serialized_options = b'\272H\010\222\001\002\010\001\310\001\001'
  _globals['_ROLEDEF'].fields_by_name['name']._loaded_options = None
  _globals['_ROLEDEF'].fields_by_name['name']._serialized_options = b'\272H\030r\0232\021^[[:word:]\\-\\.]+$\310\001\001'
  _globals['_ROLEDEF'].fields_by_name['parent_roles']._loaded_options = None
  _globals['_ROLEDEF'].fields_by_name['parent_roles']._serialized_options = b'\272H\020\222\001\n\010\001\030\001\"\004r\002\020\001\310\001\001'
  _globals['_EXPORTCONSTANTS_DEFINITIONSENTRY']._loaded_options = None
  _globals['_EXPORTCONSTANTS_DEFINITIONSENTRY']._serialized_options = b'8\001'
  _globals['_EXPORTCONSTANTS'].fields_by_name['name']._loaded_options = None
  _globals['_EXPORTCONSTANTS'].fields_by_name['name']._serialized_options = b'\272H\032r\025\020\0012\021^[[:word:]\\-\\.]+$\310\001\001'
  _globals['_CONSTANTS_LOCALENTRY']._loaded_options = None
  _globals['_CONSTANTS_LOCALENTRY']._serialized_options = b'8\001'
  _globals['_CONSTANTS'].fields_by_name['import']._loaded_options = None
  _globals['_CONSTANTS'].fields_by_name['import']._serialized_options = b'\272H\034\222\001\031\030\001\"\025r\0232\021^[[:word:]\\-\\.]+$'
  _globals['_EXPORTVARIABLES_DEFINITIONSENTRY']._loaded_options = None
  _globals['_EXPORTVARIABLES_DEFINITIONSENTRY']._serialized_options = b'8\001'
  _globals['_EXPORTVARIABLES'].fields_by_name['name']._loaded_options = None
  _globals['_EXPORTVARIABLES'].fields_by_name['name']._serialized_options = b'\272H\032r\025\020\0012\021^[[:word:]\\-\\.]+$\310\001\001'
  _globals['_VARIABLES_LOCALENTRY']._loaded_options = None
  _globals['_VARIABLES_LOCALENTRY']._serialized_options = b'8\001'
  _globals['_VARIABLES'].fields_by_name['import']._loaded_options = None
  _globals['_VARIABLES'].fields_by_name['import']._serialized_options = b'\272H\034\222\001\031\030\001\"\025r\0232\021^[[:word:]\\-\\.]+$'
  _globals['_CONDITION'].oneofs_by_name['condition']._loaded_options = None
  _globals['_CONDITION'].oneofs_by_name['condition']._serialized_options = b'\272H\002\010\001'
  _globals['_MATCH_EXPRLIST'].fields_by_name['of']._loaded_options = None
  _globals['_MATCH_EXPRLIST'].fields_by_name['of']._serialized_options = b'\272H\010\222\001\002\010\001\310\001\001'
  _globals['_MATCH'].oneofs_by_name['op']._loaded_options = None
  _globals['_MATCH'].oneofs_by_name['op']._serialized_options = b'\272H\002\010\001'
  _globals['_OUTPUT'].fields_by_name['expr']._loaded_options = None
  _globals['_OUTPUT'].fields_by_name['expr']._serialized_options = b'\030\001'
  _globals['_SCHEMAS_IGNOREWHEN'].fields_by_name['actions']._loaded_options = None
  _globals['_SCHEMAS_IGNOREWHEN'].fields_by_name['actions']._serialized_options = b'\272H\020\222\001\n\010\001\030\001\"\004r\002\020\001\310\001\001'
  _globals['_SCHEMAS_SCHEMA'].fields_by_name['ref']._loaded_options = None
  _globals['_SCHEMAS_SCHEMA'].fields_by_name['ref']._serialized_options = b'\272H\007r\002\020\001\310\001\001'
  _globals['_TESTFIXTURE_PRINCIPALS_PRINCIPALSENTRY']._loaded_options = None
  _globals['_TESTFIXTURE_PRINCIPALS_PRINCIPALSENTRY']._serialized_options = b'8\001'
  _globals['_TESTFIXTURE_PRINCIPALS_PRINCIPALGROUPSENTRY']._loaded_options = None
  _globals['_TESTFIXTURE_PRINCIPALS_PRINCIPALGROUPSENTRY']._serialized_options = b'8\001'
  _globals['_TESTFIXTURE_RESOURCES_RESOURCESENTRY']._loaded_options = None
  _globals['_TESTFIXTURE_RESOURCES_RESOURCESENTRY']._serialized_options = b'8\001'
  _globals['_TESTFIXTURE_RESOURCES_RESOURCEGROUPSENTRY']._loaded_options = None
  _globals['_TESTFIXTURE_RESOURCES_RESOURCEGROUPSENTRY']._serialized_options = b'8\001'
  _globals['_TESTFIXTURE_AUXDATA_AUXDATAENTRY']._loaded_options = None
  _globals['_TESTFIXTURE_AUXDATA_AUXDATAENTRY']._serialized_options = b'8\001'
  _globals['_TESTFIXTUREGROUP_PRINCIPALS'].fields_by_name['principals']._loaded_options = None
  _globals['_TESTFIXTUREGROUP_PRINCIPALS'].fields_by_name['principals']._serialized_options = b'\272H\020\222\001\n\010\001\030\001\"\004r\002\020\001\310\001\001'
  _globals['_TESTFIXTUREGROUP_RESOURCES'].fields_by_name['resources']._loaded_options = None
  _globals['_TESTFIXTUREGROUP_RESOURCES'].fields_by_name['resources']._serialized_options = b'\272H\020\222\001\n\010\001\030\001\"\004r\002\020\001\310\001\001'
  _globals['_TESTOPTIONS_GLOBALSENTRY']._loaded_options = None
  _globals['_TESTOPTIONS_GLOBALSENTRY']._serialized_options = b'8\001'
  _globals['_TESTSUITE_PRINCIPALSENTRY']._loaded_options = None
  _globals['_TESTSUITE_PRINCIPALSENTRY']._serialized_options = b'8\001'
  _globals['_TESTSUITE_RESOURCESENTRY']._loaded_options = None
  _globals['_TESTSUITE_RESOURCESENTRY']._serialized_options = b'8\001'
  _globals['_TESTSUITE_AUXDATAENTRY']._loaded_options = None
  _globals['_TESTSUITE_AUXDATAENTRY']._serialized_options = b'8\001'
  _globals['_TESTSUITE_PRINCIPALGROUPSENTRY']._loaded_options = None
  _globals['_TESTSUITE_PRINCIPALGROUPSENTRY']._serialized_options = b'8\001'
  _globals['_TESTSUITE_RESOURCEGROUPSENTRY']._loaded_options = None
  _globals['_TESTSUITE_RESOURCEGROUPSENTRY']._serialized_options = b'8\001'
  _globals['_TESTSUITE'].fields_by_name['name']._loaded_options = None
  _globals['_TESTSUITE'].fields_by_name['name']._serialized_options = b'\272H\007r\002\020\001\310\001\001'
  _globals['_TESTSUITE'].fields_by_name['tests']._loaded_options = None
  _globals['_TESTSUITE'].fields_by_name['tests']._serialized_options = b'\272H\010\222\001\002\010\001\310\001\001'
  _globals['_TESTTABLE_INPUT'].fields_by_name['principals']._loaded_options = None
  _globals['_TESTTABLE_INPUT'].fields_by_name['principals']._serialized_options = b'\272H\013\222\001\010\030\001\"\004r\002\020\001'
  _globals['_TESTTABLE_INPUT'].fields_by_name['resources']._loaded_options = None
  _globals['_TESTTABLE_INPUT'].fields_by_name['resources']._serialized_options = b'\272H\013\222\001\010\030\001\"\004r\002\020\001'
  _globals['_TESTTABLE_INPUT'].fields_by_name['actions']._loaded_options = None
  _globals['_TESTTABLE_INPUT'].fields_by_name['actions']._serialized_options = b'\272H\020\222\001\n\010\001\030\001\"\004r\002\020\001\310\001\001'
  _globals['_TESTTABLE_INPUT'].fields_by_name['principal_groups']._loaded_options = None
  _globals['_TESTTABLE_INPUT'].fields_by_name['principal_groups']._serialized_options = b'\272H\013\222\001\010\030\001\"\004r\002\020\001'
  _globals['_TESTTABLE_INPUT'].fields_by_name['resource_groups']._loaded_options = None
  _globals['_TESTTABLE_INPUT'].fields_by_name['resource_groups']._serialized_options = b'\272H\013\222\001\010\030\001\"\004r\002\020\001'
  _globals['_TESTTABLE_INPUT']._loaded_options = None
  _globals['_TESTTABLE_INPUT']._serialized_options = b'\272H\375\001\032\177\n\020input.principals\022-principals or principalGroups must be present\032<size(this.principals) > 0 || size(this.principal_groups) > 0\032z\n\017input.resources\022+resources or resourceGroups must be present\032:size(this.resources) > 0 || size(this.resource_groups) > 0'
  _globals['_TESTTABLE_OUTPUTEXPECTATIONS'].fields_by_name['action']._loaded_options = None
  _globals['_TESTTABLE_OUTPUTEXPECTATIONS'].fields_by_name['action']._serialized_options = b'\272H\007r\002\020\001\310\001\001'
  _globals['_TESTTABLE_OUTPUTEXPECTATIONS'].fields_by_name['expected']._loaded_options = None
  _globals['_TESTTABLE_OUTPUTEXPECTATIONS'].fields_by_name['expected']._serialized_options = b'\272H\010\222\001\002\010\001\310\001\001'
  _globals['_TESTTABLE_EXPECTATION_ACTIONSENTRY']._loaded_options = None
  _globals['_TESTTABLE_EXPECTATION_ACTIONSENTRY']._serialized_options = b'8\001'
  _globals['_TESTTABLE_EXPECTATION'].fields_by_name['actions']._loaded_options = None
  _globals['_TESTTABLE_EXPECTATION'].fields_by_name['actions']._serialized_options = b'\272H\027\232\001\021\010\001\"\004r\002\020\001*\007\202\001\004\030\001\030\002\310\001\001'
  _globals['_TESTTABLE_EXPECTATION'].fields_by_name['principals']._loaded_options = None
  _globals['_TESTTABLE_EXPECTATION'].fields_by_name['principals']._serialized_options = b'\272H\013\222\001\010\030\001\"\004r\002\020\001'
  _globals['_TESTTABLE_EXPECTATION'].fields_by_name['resources']._loaded_options = None
  _globals['_TESTTABLE_EXPECTATION'].fields_by_name['resources']._serialized_options = b'\272H\013\222\001\010\030\001\"\004r\002\020\001'
  _globals['_TESTTABLE_EXPECTATION'].fields_by_name['principal_groups']._loaded_options = None
  _globals['_TESTTABLE_EXPECTATION'].fields_by_name['principal_groups']._serialized_options = b'\272H\013\222\001\010\030\001\"\004r\002\020\001'
  _globals['_TESTTABLE_EXPECTATION'].fields_by_name['resource_groups']._loaded_options = None
  _globals['_TESTTABLE_EXPECTATION'].fields_by_name['resource_groups']._serialized_options = b'\272H\013\222\001\010\030\001\"\004r\002\020\001'
  _globals['_TESTTABLE_EXPECTATION']._loaded_options = None
  _globals['_TESTTABLE_EXPECTATION']._serialized_options = b'\272H\357\004\032\251\001\n\026expectation.principals\0229principal, principals, or principalGroups must be present\032Tthis.principal != \'\' || size(this.principals) > 0 || size(this.principal_groups) > 0\032\217\001\n%expectation.principal_nand_principals\0220principal and principals may not both be present\0324!(this.principal != \'\' && size(this.principals) > 0)\032\242\001\n\025expectation.resources\0226resource, resources, or resourceGroups must be present\032Qthis.resource != \'\' || size(this.resources) > 0 || size(this.resource_groups) > 0\032\211\001\n#expectation.resource_nand_resources\022.resource and resources may not both be present\0322!(this.resource != \'\' && size(this.resources) > 0)'
  _globals['_TESTTABLE'].fields_by_name['name']._loaded_options = None
  _globals['_TESTTABLE'].fields_by_name['name']._serialized_options = b'\272H\007r\002\020\001\310\001\001'
  _globals['_TESTTABLE'].fields_by_name['input']._loaded_options = None
  _globals['_TESTTABLE'].fields_by_name['input']._serialized_options = b'\272H\003\310\001\001'
  _globals['_TESTTABLE'].fields_by_name['expected']._loaded_options = None
  _globals['_TESTTABLE'].fields_by_name['expected']._serialized_options = b'\272H\010\222\001\002\010\001\310\001\001'
  _globals['_TEST_TESTNAME'].fields_by_name['test_table_name']._loaded_options = None
  _globals['_TEST_TESTNAME'].fields_by_name['test_table_name']._serialized_options = b'\272H\007r\002\020\001\310\001\001'
  _globals['_TEST_TESTNAME'].fields_by_name['principal_key']._loaded_options = None
  _globals['_TEST_TESTNAME'].fields_by_name['principal_key']._serialized_options = b'\272H\007r\002\020\001\310\001\001'
  _globals['_TEST_TESTNAME'].fields_by_name['resource_key']._loaded_options = None
  _globals['_TEST_TESTNAME'].fields_by_name['resource_key']._serialized_options = b'\272H\007r\002\020\001\310\001\001'
  _globals['_TEST_OUTPUTENTRIES_ENTRIESENTRY']._loaded_options = None
  _globals['_TEST_OUTPUTENTRIES_ENTRIESENTRY']._serialized_options = b'8\001'
  _globals['_TEST_EXPECTEDENTRY']._loaded_options = None
  _globals['_TEST_EXPECTEDENTRY']._serialized_options = b'8\001'
  _globals['_TEST_EXPECTEDOUTPUTSENTRY']._loaded_options = None
  _globals['_TEST_EXPECTEDOUTPUTSENTRY']._serialized_options = b'8\001'
  _globals['_TEST'].fields_by_name['name']._loaded_options = None
  _globals['_TEST'].fields_by_name['name']._serialized_options = b'\272H\003\310\001\001'
  _globals['_TEST'].fields_by_name['input']._loaded_options = None
  _globals['_TEST'].fields_by_name['input']._serialized_options = b'\272H\003\310\001\001'
  _globals['_TEST'].fields_by_name['expected']._loaded_options = None
  _globals['_TEST'].fields_by_name['expected']._serialized_options = b'\272H\027\232\001\021\010\001\"\004r\002\020\001*\007\202\001\004\030\001\030\002\310\001\001'
  _globals['_TESTRESULTS_SUITE'].fields_by_name['principals']._loaded_options = None
  _globals['_TESTRESULTS_SUITE'].fields_by_name['principals']._serialized_options = b'\030\001'
  _globals['_KIND']._serialized_start=14545
  _globals['_KIND']._serialized_end=14712
  _globals['_SCOPEPERMISSIONS']._serialized_start=14715
  _globals['_SCOPEPERMISSIONS']._serialized_end=14866
  _globals['_POLICY']._serialized_start=238
  _globals['_POLICY']._serialized_end=1068
  _globals['_POLICY_VARIABLESENTRY']._serialized_start=986
  _globals['_POLICY_VARIABLESENTRY']._serialized_end=1046
  _globals['_SOURCEATTRIBUTES']._serialized_start=1071
  _globals['_SOURCEATTRIBUTES']._serialized_end=1260
  _globals['_SOURCEATTRIBUTES_ATTRIBUTESENTRY']._serialized_start=1175
  _globals['_SOURCEATTRIBUTES_ATTRIBUTESENTRY']._serialized_end=1260
  _globals['_METADATA']._serialized_start=1263
  _globals['_METADATA']._serialized_end=1668
  _globals['_METADATA_ANNOTATIONSENTRY']._serialized_start=1606
  _globals['_METADATA_ANNOTATIONSENTRY']._serialized_end=1668
  _globals['_RESOURCEPOLICY']._serialized_start=1671
  _globals['_RESOURCEPOLICY']._serialized_end=2245
  _globals['_RESOURCERULE']._serialized_start=2248
  _globals['_RESOURCERULE']._serialized_end=2653
  _globals['_ROLEPOLICY']._serialized_start=2656
  _globals['_ROLEPOLICY']._serialized_end=2995
  _globals['_ROLERULE']._serialized_start=2998
  _globals['_ROLERULE']._serialized_end=3165
  _globals['_PRINCIPALPOLICY']._serialized_start=3168
  _globals['_PRINCIPALPOLICY']._serialized_end=3610
  _globals['_PRINCIPALRULE']._serialized_start=3613
  _globals['_PRINCIPALRULE']._serialized_end=4030
  _globals['_PRINCIPALRULE_ACTION']._serialized_start=3750
  _globals['_PRINCIPALRULE_ACTION']._serialized_end=4030
  _globals['_DERIVEDROLES']._serialized_start=4033
  _globals['_DERIVEDROLES']._serialized_end=4290
  _globals['_ROLEDEF']._serialized_start=4293
  _globals['_ROLEDEF']._serialized_end=4466
  _globals['_EXPORTCONSTANTS']._serialized_start=4469
  _globals['_EXPORTCONSTANTS']._serialized_end=4711
  _globals['_EXPORTCONSTANTS_DEFINITIONSENTRY']._serialized_start=4625
  _globals['_EXPORTCONSTANTS_DEFINITIONSENTRY']._serialized_end=4711
  _globals['_CONSTANTS']._serialized_start=4714
  _globals['_CONSTANTS']._serialized_end=4926
  _globals['_CONSTANTS_LOCALENTRY']._serialized_start=4846
  _globals['_CONSTANTS_LOCALENTRY']._serialized_end=4926
  _globals['_EXPORTVARIABLES']._serialized_start=4929
  _globals['_EXPORTVARIABLES']._serialized_end=5147
  _globals['_EXPORTVARIABLES_DEFINITIONSENTRY']._serialized_start=5085
  _globals['_EXPORTVARIABLES_DEFINITIONSENTRY']._serialized_end=5147
  _globals['_VARIABLES']._serialized_start=5150
  _globals['_VARIABLES']._serialized_end=5338
  _globals['_VARIABLES_LOCALENTRY']._serialized_start=5282
  _globals['_VARIABLES_LOCALENTRY']._serialized_end=5338
  _globals['_CONDITION']._serialized_start=5340
  _globals['_CONDITION']._serialized_end=5446
  _globals['_MATCH']._serialized_start=5449
  _globals['_MATCH']._serialized_end=5721
  _globals['_MATCH_EXPRLIST']._serialized_start=5644
  _globals['_MATCH_EXPRLIST']._serialized_end=5708
  _globals['_OUTPUT']._serialized_start=5724
  _globals['_OUTPUT']._serialized_end=5898
  _globals['_OUTPUT_WHEN']._serialized_start=5809
  _globals['_OUTPUT_WHEN']._serialized_end=5898
  _globals['_SCHEMAS']._serialized_start=5901
  _globals['_SCHEMAS']._serialized_end=6234
  _globals['_SCHEMAS_IGNOREWHEN']._serialized_start=6064
  _globals['_SCHEMAS_IGNOREWHEN']._serialized_end=6123
  _globals['_SCHEMAS_SCHEMA']._serialized_start=6125
  _globals['_SCHEMAS_SCHEMA']._serialized_end=6234
  _globals['_TESTFIXTURE']._serialized_start=6237
  _globals['_TESTFIXTURE']._serialized_end=7341
  _globals['_TESTFIXTURE_PRINCIPALS']._serialized_start=6253
  _globals['_TESTFIXTURE_PRINCIPALS']._serialized_end=6698
  _globals['_TESTFIXTURE_PRINCIPALS_PRINCIPALSENTRY']._serialized_start=6493
  _globals['_TESTFIXTURE_PRINCIPALS_PRINCIPALSENTRY']._serialized_end=6583
  _globals['_TESTFIXTURE_PRINCIPALS_PRINCIPALGROUPSENTRY']._serialized_start=6585
  _globals['_TESTFIXTURE_PRINCIPALS_PRINCIPALGROUPSENTRY']._serialized_end=6698
  _globals['_TESTFIXTURE_RESOURCES']._serialized_start=6701
  _globals['_TESTFIXTURE_RESOURCES']._serialized_end=7133
  _globals['_TESTFIXTURE_RESOURCES_RESOURCESENTRY']._serialized_start=6932
  _globals['_TESTFIXTURE_RESOURCES_RESOURCESENTRY']._serialized_end=7020
  _globals['_TESTFIXTURE_RESOURCES_RESOURCEGROUPSENTRY']._serialized_start=7022
  _globals['_TESTFIXTURE_RESOURCES_RESOURCEGROUPSENTRY']._serialized_end=7133
  _globals['_TESTFIXTURE_AUXDATA']._serialized_start=7136
  _globals['_TESTFIXTURE_AUXDATA']._serialized_end=7341
  _globals['_TESTFIXTURE_AUXDATA_AUXDATAENTRY']._serialized_start=7256
  _globals['_TESTFIXTURE_AUXDATA_AUXDATAENTRY']._serialized_end=7341
  _globals['_TESTFIXTUREGROUP']._serialized_start=7344
  _globals['_TESTFIXTUREGROUP']._serialized_end=7493
  _globals['_TESTFIXTUREGROUP_PRINCIPALS']._serialized_start=7364
  _globals['_TESTFIXTUREGROUP_PRINCIPALS']._serialized_end=7429
  _globals['_TESTFIXTUREGROUP_RESOURCES']._serialized_start=7431
  _globals['_TESTFIXTUREGROUP_RESOURCES']._serialized_end=7493
  _globals['_TESTOPTIONS']._serialized_start=7496
  _globals['_TESTOPTIONS']._serialized_end=7813
  _globals['_TESTOPTIONS_GLOBALSENTRY']._serialized_start=7731
  _globals['_TESTOPTIONS_GLOBALSENTRY']._serialized_end=7813
  _globals['_TESTSUITE']._serialized_start=7816
  _globals['_TESTSUITE']._serialized_end=8997
  _globals['_TESTSUITE_PRINCIPALSENTRY']._serialized_start=6493
  _globals['_TESTSUITE_PRINCIPALSENTRY']._serialized_end=6583
  _globals['_TESTSUITE_RESOURCESENTRY']._serialized_start=6932
  _globals['_TESTSUITE_RESOURCESENTRY']._serialized_end=7020
  _globals['_TESTSUITE_AUXDATAENTRY']._serialized_start=7256
  _globals['_TESTSUITE_AUXDATAENTRY']._serialized_end=7341
  _globals['_TESTSUITE_PRINCIPALGROUPSENTRY']._serialized_start=6585
  _globals['_TESTSUITE_PRINCIPALGROUPSENTRY']._serialized_end=6698
  _globals['_TESTSUITE_RESOURCEGROUPSENTRY']._serialized_start=7022
  _globals['_TESTSUITE_RESOURCEGROUPSENTRY']._serialized_end=7133
  _globals['_TESTTABLE']._serialized_start=9000
  _globals['_TESTTABLE']._serialized_end=11201
  _globals['_TESTTABLE_INPUT']._serialized_start=9337
  _globals['_TESTTABLE_INPUT']._serialized_end=9888
  _globals['_TESTTABLE_OUTPUTEXPECTATIONS']._serialized_start=9891
  _globals['_TESTTABLE_OUTPUTEXPECTATIONS']._serialized_end=10019
  _globals['_TESTTABLE_EXPECTATION']._serialized_start=10022
  _globals['_TESTTABLE_EXPECTATION']._serialized_end=11201
  _globals['_TESTTABLE_EXPECTATION_ACTIONSENTRY']._serialized_start=10487
  _globals['_TESTTABLE_EXPECTATION_ACTIONSENTRY']._serialized_end=10571
  _globals['_TEST']._serialized_start=11204
  _globals['_TEST']._serialized_end=12190
  _globals['_TEST_TESTNAME']._serialized_start=11660
  _globals['_TEST_TESTNAME']._serialized_end=11818
  _globals['_TEST_OUTPUTENTRIES']._serialized_start=11821
  _globals['_TEST_OUTPUTENTRIES']._serialized_end=11997
  _globals['_TEST_OUTPUTENTRIES_ENTRIESENTRY']._serialized_start=11915
  _globals['_TEST_OUTPUTENTRIES_ENTRIESENTRY']._serialized_end=11997
  _globals['_TEST_EXPECTEDENTRY']._serialized_start=11999
  _globals['_TEST_EXPECTEDENTRY']._serialized_end=12084
  _globals['_TEST_EXPECTEDOUTPUTSENTRY']._serialized_start=12086
  _globals['_TEST_EXPECTEDOUTPUTSENTRY']._serialized_end=12190
  _globals['_TESTRESULTS']._serialized_start=12193
  _globals['_TESTRESULTS']._serialized_end=14542
  _globals['_TESTRESULTS_TALLY']._serialized_start=12334
  _globals['_TESTRESULTS_TALLY']._serialized_end=12425
  _globals['_TESTRESULTS_SUMMARY']._serialized_start=12428
  _globals['_TESTRESULTS_SUMMARY']._serialized_end=12621
  _globals['_TESTRESULTS_SUITE']._serialized_start=12624
  _globals['_TESTRESULTS_SUITE']._serialized_end=12973
  _globals['_TESTRESULTS_TESTCASE']._serialized_start=12975
  _globals['_TESTRESULTS_TESTCASE']._serialized_end=13078
  _globals['_TESTRESULTS_PRINCIPAL']._serialized_start=13080
  _globals['_TESTRESULTS_PRINCIPAL']._serialized_end=13181
  _globals['_TESTRESULTS_RESOURCE']._serialized_start=13183
  _globals['_TESTRESULTS_RESOURCE']._serialized_end=13277
  _globals['_TESTRESULTS_ACTION']._serialized_start=13279
  _globals['_TESTRESULTS_ACTION']._serialized_end=13372
  _globals['_TESTRESULTS_DETAILS']._serialized_start=13375
  _globals['_TESTRESULTS_DETAILS']._serialized_end=13710
  _globals['_TESTRESULTS_OUTPUTFAILURE']._serialized_start=13713
  _globals['_TESTRESULTS_OUTPUTFAILURE']._serialized_end=14125
  _globals['_TESTRESULTS_OUTPUTFAILURE_MISMATCHEDVALUE']._serialized_start=13929
  _globals['_TESTRESULTS_OUTPUTFAILURE_MISMATCHEDVALUE']._serialized_end=14046
  _globals['_TESTRESULTS_OUTPUTFAILURE_MISSINGVALUE']._serialized_start=14048
  _globals['_TESTRESULTS_OUTPUTFAILURE_MISSINGVALUE']._serialized_end=14114
  _globals['_TESTRESULTS_FAILURE']._serialized_start=14128
  _globals['_TESTRESULTS_FAILURE']._serialized_end=14312
  _globals['_TESTRESULTS_SUCCESS']._serialized_start=14314
  _globals['_TESTRESULTS_SUCCESS']._serialized_end=14430
  _globals['_TESTRESULTS_RESULT']._serialized_start=14432
  _globals['_TESTRESULTS_RESULT']._serialized_end=14542
# @@protoc_insertion_point(module_scope)



from buf.validate import validate_pb2 as _validate_pb2
from cerbos.cloud.bundle.v1 import bundle_pb2 as _bundle_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PDPConfig(_message.Message):
    __slots__ = ["meta", "bundle_info"]
    class Meta(_message.Message):
        __slots__ = ["created_at", "commit_hash"]
        CREATED_AT_FIELD_NUMBER: _ClassVar[int]
        COMMIT_HASH_FIELD_NUMBER: _ClassVar[int]
        created_at: _timestamp_pb2.Timestamp
        commit_hash: str
        def __init__(self, created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., commit_hash: _Optional[str] = ...) -> None: ...
    META_FIELD_NUMBER: _ClassVar[int]
    BUNDLE_INFO_FIELD_NUMBER: _ClassVar[int]
    meta: PDPConfig.Meta
    bundle_info: _bundle_pb2.BundleInfo
    def __init__(self, meta: _Optional[_Union[PDPConfig.Meta, _Mapping]] = ..., bundle_info: _Optional[_Union[_bundle_pb2.BundleInfo, _Mapping]] = ...) -> None: ...
